#!/bin/bash
#
# uls_update.sh
#
# ULS-Software updaten
#
# Aufruf: uls_update.sh [-h <old-version>] [-v <old-version>] [-C <mysql-defaults-file>] [<db-user> [<db-Kennwort>]]
#         -v <old-version>    Die Skripts zum Update von der
#                             Version <old-version> ausgefhrt,
#                             auch wenn die Datenbank schon eine
#                             hhere Version hat.
#         -h <old-version>    Es werden nur die Hilfetexte der Version <old-version>
#                             neu eingelesen
#         -C <mysql-defaults-file> File mit User, Password, Socket
#
#############################################################
#
unset OLDVERSION HELP MYSQLDEFAULTSFILE
#
while getopts C:v:h:? op
 do
  case "$op" in
   C) MYSQLDEFAULTSFILE="$OPTARG";;
   v) OLDVERSION="-v $OPTARG";;
   h) HELP="-h $OPTARG";;
   *) echo "usage: $0 [-h <old-version>|-v <old-version>] [-C <mysql-defaults-file>] [<db-user> [<db-Kennwort>]]"
      exit 1;;
  esac
done
shift $(( $OPTIND -1))
#
if [[ -z "$MYSQLDEFAULTSFILE" && $# -lt 1 ]]
 then
  echo "usage: $0 [-h <old-version>|-v <old-version>] [-C <mysql-defaults-file>] [<db-User> [<db-Kennwort>]]"
  exit 1
fi
#
if [[ -z "$MYSQLDEFAULTSFILE" && -z "$2" ]]
 then
  echo "Bitte MySQL-Kennwort fuer User $1 eingeben:"
  read -s DBPWD
else
  DBPWD="$2"
fi
#
unset CLEANFILE
#
if [[ -z "$MYSQLDEFAULTSFILE" ]]
 then
  MYSQLDEFAULTSFILE=/dev/shm/.ulsupdate.my.cnf
  CLEANFILE="-C"
cat >$MYSQLDEFAULTSFILE  <<EOF
[client]
user=$1
password=$DBPWD
EOF
  chmod 600 $MYSQLDEFAULTSFILE
  #
  if [[ -f /etc/unix2web/uls.conf ]] && grep -q '^[^#].*MYSQL_UNIX_PORT' /etc/unix2web/uls.conf
   then
    UP=`awk -F '=' '$1 ~ "^[^#].*MYSQL_UNIX_PORT" {print $2}' /etc/unix2web/uls.conf`
    if [[ -n "$UP" ]]
     then
      echo "socket=$UP" >>$MYSQLDEFAULTSFILE
    fi
  elif [[ -f /etc/unix2web/uls-https.conf ]] && grep -q '^[^#].*MYSQL_UNIX_PORT' /etc/unix2web/uls-https.conf
   then
    UP=`awk -F '=' '$1 ~ "^[^#].*MYSQL_UNIX_PORT" {print $2}' /etc/unix2web/uls-https.conf`
    if [[ -n "$UP" ]]
     then
      echo "socket=$UP" >>$MYSQLDEFAULTSFILE
    fi
  fi
fi
#
cd `dirname $0`
#
echo "Die Verarbeitung wird im Hintergrund gestartet."
echo "Die Ausgaben werden zusaetzlich in /tmp/uls_update.log geschrieben."
echo
sleep 5
#
>/tmp/uls_update.log
./uls_update_batch.sh $HELP $OLDVERSION $CLEANFILE "$MYSQLDEFAULTSFILE" >>/tmp/uls_update.log 2>&1 &
tail -f --pid=$! /tmp/uls_update.log
