set @@character_set_client = 'utf8';

-- Suchtabellen *dates bereinigen
-- wird von cleanvalues aufgerufen


delimiter //

DROP procedure IF EXISTS cleandatetables//
create procedure cleandatetables()
  deterministic
  sql security invoker
  begin
    declare i, z, dtflag integer;

-- Wertedates

    select now() AS 'start cleandatetables';

    -- nicht mehr vorhandene werteindizesID loeschen
    create temporary table wzi (primary key (werteindizesID))
      select distinct werteindizesID from wertedates;

    select now() as 'delete wzi';
    delete wzi from wzi join wi on wi.ID = wzi.werteindizesID;
    select now() AS 'delete wertedates without werteindizes';
    delete wertedates from wertedates join wzi using(werteindizesID);

    drop temporary table wzi;

    select now() AS `delete wertedates`;

    -- bei limits mit "diffto" duerfen die refenzierten Werte nicht geloescht werden
    set dtflag = 0;
    if (select count(*) from difftos) > 0 then
      create temporary table loggingtmp.savedt (primary key(werteindizesID))
        select wd.werteindizesID, wd.serverID, wd.accessID, wd.sectionID, wd.teststepID,
          wd.teststepdetailsID, difftos.d as fdate
        from wertedates as wd
        join wi on wi.ID = wd.werteindizesID and fdate < wi.testdatum and wi.testdatum <= ldate
        join difftos
          on difftos.ID = wi.ID and difftos.d < wi.testdatum and difftos.d = fdate and difftos.d != ldate;
      if row_count() > 0 then
        set dtflag = 1;
      else
        drop temporary table loggingtmp.savedt;
      end if;
    end if;

    -- wertedates loeschen, wenn Endedatum kleiner als Aufbewahrungsdatum
    -- und kein Eintrag in "diffto"
    delete wertedates from wertedates
      join wi on wi.ID = wertedates.werteindizesID and ldate < wi.testdatum
      left join difftos on difftos.ID = wi.ID and difftos.d = fdate and difftos.d = ldate
      where difftos.ID is NULL;

    -- Zeitraeume mit Ueberschneidung loeschen (sollten eigentlich nicht vorkommen)
    if (select count(*) from wertedates as wl
        join wi on wi.ID = wl.werteindizesID and wl.fdate <= wi.testdatum
        join wertedates as wg
          on wg.werteindizesID = wl.werteindizesID
            and wl.fdate < wg.fdate and wg.fdate <= wl.ldate) > 0 then
      create temporary table loggingtmp.wld (primary key(werteindizesID, fdate))
        select wl.werteindizesID, wl.fdate, wl.ldate, max(wg.ldate) as mldate
        from wertedates as wl
        join wi on wi.ID = wl.werteindizesID and wl.fdate <= wi.testdatum
        join wertedates as wg using(werteindizesID)
        where wl.fdate < wg.fdate and wg.fdate <= wl.ldate
        group by werteindizesID, wl.fdate;
      update wertedates
        join loggingtmp.wld using(werteindizesID, fdate)
        set wertedates.ldate = wld.mldate
        where wertedates.ldate < wld.mldate;
      delete wertedates from wertedates
        join loggingtmp.wld using(werteindizesID)
        where wertedates.fdate > wld.fdate and wertedates.fdate <= wld.mldate;
      drop temporary table loggingtmp.wld;
    end if;

    -- Anfangsdatum updaten, wenn Anfangsdatum kleiner Aufbewahrung und Endedatum groesser gleich Aufbewahrung
    update wertedates
      join wi on wi.ID = wertedates.werteindizesID and fdate < wi.testdatum and wi.testdatum <= ldate
      set fdate = wi.testdatum;

    -- wenn "difftos" vorhanden, dann "diffto" Datumswerte einfuegen
    if dtflag = 1 then
      insert ignore into wertedates
        (werteindizesID, serverID, accessID, sectionID, teststepID, teststepdetailsID, fdate, ldate)
      select werteindizesID, serverID, accessID, sectionID, teststepID, teststepdetailsID, fdate, fdate
      from loggingtmp.savedt;
      drop temporary table loggingtmp.savedt;
    end if;

    select now() AS 'optimize table wertedates';
    optimize table wertedates;

-- Teststepdates

    select now() AS 'create temporary table wzs';
    create temporary table wzs
      select * from wertedates;

    select now() AS 'create temporary table ssda';
    create temporary table ssda
      (primary key(serverID, accessID, sectionID, teststepID, fdate))
      select serverID, sectionID, teststepID, accessID, min(fdate) as fdate
      from wzs
      group by serverID, accessID, sectionID, teststepID;

    select now() AS 'delete teststepdates';
    delete teststepdates
      from teststepdates left join ssda using(serverID, accessID, sectionID, teststepID)
      where ssda.serverID is NULL;
    delete teststepdates
      from teststepdates join ssda using(serverID, accessID, sectionID, teststepID)
      where teststepdates.ldate < ssda.fdate;

    select now() AS 'update teststepdates';
    -- Zeitraeume mit Ueberschneidung loeschen (sollten eigentlich nicht vorkommen)
    if (select count(*) from teststepdates as tl
        join ssda using(serverID, accessID, sectionID, teststepID)
        join teststepdates as tg
          using(serverID, accessID, sectionID, teststepID)
        where tl.fdate <= ssda.fdate and tl.fdate < tg.fdate and tg.fdate <= tl.ldate) > 0 then
      create temporary table loggingtmp.tld (primary key(serverID, accessID, sectionID, teststepID, fdate))
        select serverID, accessID, sectionID, teststepID, tl.fdate, max(tg.ldate) as mldate
        from teststepdates as tl
        join ssda using(serverID, accessID, sectionID, teststepID)
        join teststepdates as tg using(serverID, accessID, sectionID, teststepID)
        where tl.fdate <= ssda.fdate and tl.fdate < tg.fdate and tg.fdate <= tl.ldate
        group by serverID, accessID, sectionID, teststepID, tl.fdate;
      update teststepdates
        join loggingtmp.tld using(serverID, accessID, sectionID, teststepID, fdate)
        set teststepdates.ldate = tld.mldate
        where teststepdates.ldate < tld.mldate;
      delete teststepdates from teststepdates
        join loggingtmp.tld using(serverID, accessID, sectionID, teststepID)
        where teststepdates.fdate > tld.fdate and teststepdates.fdate <= tld.mldate;
      drop temporary table loggingtmp.tld;
    end if;

    update teststepdates join ssda using(serverID, sectionID, teststepID, accessID)
      set teststepdates.fdate = ssda.fdate
      where teststepdates.fdate < ssda.fdate and ssda.fdate <= teststepdates.ldate;

    select now() AS 'optimize table teststepdates';
    optimize table teststepdates;

-- Sectiondates

    select now() AS 'create temporary table ssa';
    create temporary table ssa
      (primary key(serverID, sectionID, accessID, fdate))
      select serverID, sectionID, accessID, min(fdate) as fdate
      from ssda
      group by serverID, sectionID, accessID;

    select now() AS 'delete sectiondates';
    delete sectiondates
      from sectiondates left join ssa using(serverID, sectionID, accessID)
      where ssa.serverID is NULL;
    delete sectiondates
      from sectiondates join ssa using(serverID, sectionID, accessID)
      where sectiondates.ldate < ssa.fdate;

    select now() AS 'update sectiondates';
    -- Zeitraeume mit Ueberschneidung loeschen (sollten eigentlich nicht vorkommen)
    if (select count(*) from sectiondates as sl
        join ssa using(serverID, sectionID, accessID)
        join sectiondates as sg
        using(serverID, accessID, sectionID)
        where sl.fdate <= ssa.fdate and sl.fdate < sg.fdate and sg.fdate <= sl.ldate) > 0 then
      create temporary table loggingtmp.sld (primary key(serverID, accessID, sectionID, fdate))
        select serverID, accessID, sectionID, sl.fdate, max(sg.ldate) as mldate
        from sectiondates as sl
        join ssa using(serverID, sectionID, accessID)
        join sectiondates as sg using(serverID, accessID, sectionID)
        where sl.fdate <= ssa.fdate and sl.fdate < sg.fdate and sg.fdate <= sl.ldate
        group by serverID, accessID, sectionID, sl.fdate;
      update sectiondates
        join loggingtmp.sld using(serverID, accessID, sectionID, fdate)
        set sectiondates.ldate = sld.mldate
        where sectiondates.ldate < sld.mldate;
      delete sectiondates from sectiondates
        join loggingtmp.sld using(serverID, accessID, sectionID)
        where sectiondates.fdate > sld.fdate and sectiondates.fdate <= sld.mldate;
      drop temporary table loggingtmp.sld;
    end if;

    update sectiondates join ssa using(serverID, sectionID, accessID)
      set sectiondates.fdate = ssa.fdate
      where sectiondates.fdate < ssa.fdate and ssa.fdate <= sectiondates.ldate;

    select now() AS 'optimize table sectiondates';
    optimize table sectiondates;

-- Serverdates

    select now() AS 'create temporary table sa';
    create temporary table sa
      (primary key(serverID, accessID, fdate))
      select serverID, accessID, min(fdate) as fdate
      from ssa
      group by serverID, accessID;

    select now() AS 'delete serverdates';
    delete serverdates
      from serverdates left join sa using(serverID, accessID)
      where sa.serverID is NULL;
    delete serverdates
      from serverdates join sa using(serverID, accessID)
      where serverdates.ldate < sa.fdate;

    select now() AS 'update serverdates';
    -- Zeitraeume mit Ueberschneidung loeschen (sollten eigentlich nicht vorkommen)
    if (select count(*) from serverdates as sl
        join sa using(serverID, accessID)
        join serverdates as sg
        using(serverID, accessID)
        where sl.fdate <= sa.fdate and sl.fdate < sg.fdate and sg.fdate <= sl.ldate) > 0 then
      create temporary table loggingtmp.sld (primary key(serverID, accessID, fdate))
        select serverID, accessID, sl.fdate, max(sg.ldate) as mldate
        from serverdates as sl
        join sa using(serverID, accessID)
        join serverdates as sg using(serverID, accessID)
        where sl.fdate <= sa.fdate and sl.fdate < sg.fdate and sg.fdate <= sl.ldate
        group by serverID, accessID, sl.fdate;
      update serverdates
        join loggingtmp.sld using(serverID, accessID, fdate)
        set serverdates.ldate = sld.mldate
        where serverdates.ldate < sld.mldate;
      delete serverdates from serverdates
        join loggingtmp.sld using(serverID, accessID)
        where serverdates.fdate > sld.fdate and serverdates.fdate <= sld.mldate;
      drop temporary table loggingtmp.sld;
    end if;

    update serverdates join sa using(serverID, accessID)
      set serverdates.fdate = sa.fdate
      where serverdates.fdate < sa.fdate and sa.fdate <= serverdates.ldate;

    select now() AS 'optimize table serverdates';
    optimize table serverdates;

-- fertig

    drop temporary table ssda, ssa, sa, wzs;

    select now() AS 'finished cleandatetables';

  end//

GRANT EXECUTE on PROCEDURE cleandatetables to loggingadmin@'localhost'//
