set @@character_set_client = 'utf8';

delimiter //

DROP procedure IF EXISTS cleanlwerte//
create procedure cleanlwerte()
  deterministic
  sql security invoker
  begin
    declare z integer;
    declare i, daysh, daysd, daysw, daysm, dayss integer unsigned;
    declare td, md date;
    declare lwinosrvcur cursor for
      select ID from lnames where verfahrenID is NULL order by ID;
    declare srvnosrvcur cursor for
      select serverID from lnames where verfahrenID is NULL order by ID;
    declare lwicur cursor for
      select ID, testdate from lwi order by ID;
    declare continue handler for not found set z = 1;

    set daysh = coalesce((select wert+0 from systemvars
                          where name = 'StoretimeCompHour' AND wert+0 > 0), 180);
    set daysd = coalesce((select wert+0 from systemvars
                          where name = 'StoretimeCompDay' AND wert+0 > 0), 370);
    set daysw = coalesce((select wert+0 from systemvars
                          where name = 'StoretimeCompWeek' AND wert+0 > 0), 740);
    set daysm = coalesce((select wert+0 from systemvars
                          where name = 'StoretimeCompMonth' AND wert+0 > 0), 740);
    set dayss = coalesce((select wert+0 from systemvars
                          where name = 'StoretimeCompSpecial' AND wert+0 > 0), 370);
 
    select now() as 'start cleanlwerte';

    create temporary table lnames (primary key(ID), key vID(verfahrenID, accessID))
      select lw.ID, period, lw.groupfunctionsID, verfahrenID, accessID,
        serverID, sectionID, teststepID,
        verfahren.name as domainname, servername, e.name as secname,
        t.name as tstname, d.name as detname, u.name as unit
      from lwerteindizes as lw
      join section as e on e.ID = lw.sectionID
      join teststep as t on t.ID = lw.teststepID
      join teststepdetails as d on d.ID = lw.teststepdetailsID
      join einheiten as u on u.ID = d.einheitID
      left join server as s on s.ID = lw.serverID
      left join verfahren on verfahren.ID = verfahrenID;

    -- Mindesttage Aufbewahrung pro lwerteindizesID
    -- laut Autoaufbewahrung
    select now() as 'create temporary table va';
    create temporary table va (primary key(ID))
      select lnames.ID, max(a.mindesttage) as mt
      from lnames
      join kautoaufbewahrung as a using(verfahrenID, accessID)
      where a.mindesttage > 0 and a.aktiv = '1'
        and testreg(servername, a.server, a.server_v)
        and testreg(secname, a.section, a.section_v)
        and testreg(tstname, a.teststep, a.teststep_v)
        and testreg(detname, a.details, a.details_v)
        and testreg(unit, a.einheit, a.einheit_v)
        and find_in_set(lnames.groupfunctionsID, a.groupfunctionIDs)
        and find_in_set(lnames.period, a.period)
      group by lnames.ID;

    -- Mindesttage Aufbewahrung pro lwerteindizesID
    -- laut Gruppen-Autoaufbewahrung
    select now() as 'create temporary table ga';
    create temporary table ga (primary key(ID))
      select lnames.ID, max(g.mindesttage) as mt
      from lnames
      join gruppenrechte as gr
        on gr.admin = '1' and gr.verfahrenID = lnames.verfahrenID and gr.accessID = lnames.accessID
      join gautocrettime as g
        on g.groupID = gr.gruppenID and g.accessID = lnames.accessID and g.mindesttage > 0
          and g.aktiv = '1'
          and testreg(domainname, g.domain, g.domain_v)
          and testreg(servername, g.server, g.server_v)
          and testreg(secname, g.section, g.section_v)
          and testreg(tstname, g.teststep, g.teststep_v)
          and testreg(detname, g.details, g.details_v)
          and testreg(unit, g.einheit, g.einheit_v)
          and find_in_set(lnames.groupfunctionsID, g.groupfunctionIDs)
          and find_in_set(lnames.period, g.period)
      group by lnames.ID;

    -- resultierende Aufbewahrung pro lwerteindizesID
    select now() as 'create temporary table lwi';
    create temporary table lwi (primary key(ID))
      select lw.ID, lw.serverID, lw.sectionID, lw.teststepID, lw.accessID, lw.period,
        date(now() + interval 6 hour) - interval
          greatest(coalesce(va.mt, ga.mt,
              case lw.period
                when 'Day' then daysd
                when 'Week' then daysw
                when 'Month' then daysm
                when 'special' then dayss
                else daysh end),
            coalesce(va.mt, 0), coalesce(ga.mt, 0)) day as testdate
      from lnames as lw
      left join va on va.ID = lw.ID
      left join ga on ga.ID = lw.ID
      where serverID is not NULL;

    if exists (select * from lnames where verfahrenID is NULL) then
      select now() as 'delete from lwerte, mwerte for deleted servers';
      set z = 0;
      open lwinosrvcur;
      fetch lwinosrvcur into i;
      while z != 1
       do
        delete from lwerte where lwerteindizesID = i;
        delete from mwerte where lwerteindizesID = i;
        fetch lwinosrvcur into i;
      end while;
      close lwinosrvcur;
      select now() as 'delete from datetables for deleted servers';
      set z = 0;
      open srvnosrvcur;
      fetch srvnosrvcur into i;
      while z != 1
       do
        delete from lwertedates where serverID = i;
        delete from lteststepdates where serverID = i;
        delete from lsectiondates where serverID = i;
        delete from lserverdates where serverID = i;
        fetch srvnosrvcur into i;
      end while;
      close srvnosrvcur;
    end if;

    select now() as 'delete from lwerte, mwerte, lwertedates / update lwertedates';
    set z = 0;
    open lwicur;
    fetch lwicur into i, td;
    while z != 1
     do
      delete from lwerte where lwerteindizesID = i and datum < td;
      delete from mwerte where lwerteindizesID = i and datum < td;
      delete from lwertedates where lwerteindizesID = i and ldate < td;
      set md = (select max(ldate) from lwertedates where lwerteindizesID = i and fdate < td);
      if md is NOT NULL then
        if exists (select * from lwertedates where lwerteindizesID = i and fdate = td) then
          if (select ldate < md from lwertedates where lwerteindizesID = i and fdate = td) then
            update lwertedates set ldate = md where lwerteindizesID = i and fdate = td;
          end if;
          delete from lwertedates where lwerteindizesID = i and fdate < td;
        else
          update lwertedates set fdate = td where lwerteindizesID = i and fdate < td and td <= ldate;
        end if;
      end if;
      fetch lwicur into i, td;
    end while;
    close lwicur;

    drop temporary table va, ga, lwi, lnames;

    select now() as 'optimize table lwerte';
    optimize table lwerte;
    select now() as 'optimize table mwerte';
    optimize table mwerte;
    select now() as 'optimize table lwertedates';
    optimize table lwertedates;


    -- Temp-Tabelle fuer lteststepdates erstellen
    select now() as 'create temporary table ltd';
    create temporary table ltd
      (primary key(serverID, accessID, sectionID, teststepID, period, fdate))
      select serverID, accessID, sectionID, teststepID, period, min(fdate) as fdate
      from lwertedates
      group by serverID, accessID, sectionID, teststepID, period;

    select now() as 'delete lteststepdates';
    delete lteststepdates
      from lteststepdates
      left join ltd using(serverID, accessID, sectionID, teststepID, period)
      where ltd.serverID is NULL OR lteststepdates.ldate < ltd.fdate;
    select now() as 'update lteststepdates';
    -- Zeitraeume mit Ueberschneidung loeschen - sicher ist sicher
    if (select count(*) from lteststepdates as tl
        join ltd using(serverID, accessID, sectionID, teststepID, period, fdate)
        join lteststepdates as tg
          using(serverID, accessID, sectionID, teststepID, period)
        where tl.fdate <= ltd.fdate and tl.fdate < tg.fdate and tg.fdate <= tl.ldate) > 0 then
      create temporary table loggingtmp.tld (primary key(serverID, accessID, sectionID, teststepID, period, fdate))
        select serverID, accessID, sectionID, teststepID, period, tl.fdate, max(tg.ldate) as mldate
        from lteststepdates as tl
        join ltd using(serverID, accessID, sectionID, teststepID, period)
        join lteststepdates as tg using(serverID, accessID, sectionID, teststepID, period)
        where tl.fdate <= ltd.fdate and tl.fdate < tg.fdate and tg.fdate <= tl.ldate
        group by serverID, accessID, sectionID, teststepID, period, tl.fdate;
      update lteststepdates
        join loggingtmp.tld using(serverID, accessID, sectionID, teststepID, period, fdate)
        set lteststepdates.ldate = tld.mldate;
      delete lteststepdates from lteststepdates
        join loggingtmp.tld using(serverID, accessID, sectionID, teststepID, period)
        where lteststepdates.fdate > tld.fdate and lteststepdates.fdate <= tld.mldate;
      drop temporary table loggingtmp.tld;
    end if;
    update lteststepdates
      join ltd using(serverID, accessID, sectionID, teststepID, period)
      set lteststepdates.fdate = ltd.fdate
      where lteststepdates.fdate < ltd.fdate AND ltd.fdate <= lteststepdates.ldate;

    select now() as 'optimize table lteststepdates';
    optimize table lteststepdates;


    -- Temp-Tabelle fuer lsectiondates erstellen
    select now() as 'create temporary table lte';
    create temporary table lte
      (primary key(`serverID`,`accessID`,`sectionID`,`period`,`fdate`))
      select serverID, accessID, sectionID, period, min(fdate) as fdate
      from ltd
      group by serverID, accessID, sectionID, period;
    select now() as 'delete lsectiondates';
    delete lsectiondates
      from lsectiondates
      left join lte using(serverID, accessID, sectionID, period)
      where lte.serverID is NULL OR lsectiondates.ldate < lte.fdate;
    select now() as 'update lsectiondates';
    -- Zeitraeume mit Ueberschneidung loeschen - sicher ist sicher
    if (select count(*) from lsectiondates as sl
        join lte using(serverID, accessID, sectionID, period, fdate)
        join lsectiondates as sg
        using(serverID, accessID, sectionID, period)
        where sl.fdate < sg.fdate and sg.fdate <= sl.ldate) > 0 then
      create temporary table loggingtmp.sld (primary key(serverID, accessID, sectionID, period, fdate))
        select serverID, accessID, sectionID, period, sl.fdate, max(sg.ldate) as mldate
        from lsectiondates as sl
        join lte using(serverID, accessID, sectionID, period)
        join lsectiondates as sg using(serverID, accessID, sectionID, period)
        where sl.fdate <= lte.fdate and sl.fdate < sg.fdate and sg.fdate <= sl.ldate
        group by serverID, accessID, sectionID, period, sl.fdate;
      update lsectiondates
        join loggingtmp.sld using(serverID, accessID, sectionID, period, fdate)
        set lsectiondates.ldate = sld.mldate
        where lsectiondates.ldate < sld.mldate;
      delete lsectiondates from lsectiondates
        join loggingtmp.sld using(serverID, accessID, sectionID, period)
        where lsectiondates.fdate > sld.fdate and lsectiondates.fdate <= sld.mldate;
      drop temporary table loggingtmp.sld;
    end if;
    update lsectiondates
      join lte using(serverID, accessID, sectionID, period)
      set lsectiondates.fdate = lte.fdate
      where lsectiondates.fdate < lte.fdate AND lsectiondates.ldate >= lte.fdate;

    select now() as 'optimize table lsectiondates';
    optimize table lsectiondates;
    drop temporary table ltd;


    -- Temp-Tabelle fuer lserverdates erstellen
    select now() as 'create temporary table lts';
    create temporary table lts
      (primary key(`serverID`,`accessID`,`period`,`fdate`))
      select serverID, accessID, period, min(fdate) as fdate
      from lte
      group by serverID, accessID, period;
    select now() as 'delete lserverdates';
    delete lserverdates
      from lserverdates
      left join lts using(serverID, accessID, period)
      where lts.serverID is NULL OR lserverdates.ldate < lts.fdate;
    select now() as 'update lserverdates';
    -- Zeitraeume mit Ueberschneidung loeschen - sicher ist sicher
    if (select count(*) from lserverdates as sl
        join lts using(serverID, accessID, period)
        join lserverdates as sg
        using(serverID, accessID, period)
        where sl.fdate <= lts.fdate and sl.fdate < sg.fdate and sg.fdate <= sl.ldate) > 0 then
      create temporary table loggingtmp.sld (primary key(serverID, accessID, period, fdate))
        select serverID, accessID, period, sl.fdate, max(sg.ldate) as mldate
        from lserverdates as sl
        join lts using(serverID, accessID, period)
        join lserverdates as sg using(serverID, accessID, period)
        where sl.fdate <= lts.fdate and sl.fdate < sg.fdate and sg.fdate <= sl.ldate
        group by serverID, accessID, period, sl.fdate;
      update lserverdates
        join loggingtmp.sld using(serverID, accessID, period, fdate)
        set lserverdates.ldate = sld.mldate
        where lserverdates.ldate < sld.mldate;
      delete lserverdates from lserverdates
        join loggingtmp.sld using(serverID, accessID, period)
        where lserverdates.fdate > sld.fdate and lserverdates.fdate <= sld.mldate;
      drop temporary table loggingtmp.sld;
    end if;
    update lserverdates
      join lts using(serverID, accessID, period)
      set lserverdates.fdate = lts.fdate
      where lserverdates.fdate < lts.fdate AND lserverdates.ldate >= lts.fdate;

    select now() as 'optimize table lserverdates';
    optimize table lserverdates;
    drop temporary table lte, lts;

  end//
