set @@character_set_client = 'utf8';

delimiter //

drop trigger if exists clientsuspensions_au//
create trigger clientsuspensions_au after update on clientsuspensions
  for each row 
begin
  insert into changeprot
    (domainID, accessID, changedtable, tableID, userID, username, action,
     classes, server, section, teststep, details, unit, newvalues)
  select NEW.domainID, NEW.accessID, 'clientsuspensions', NEW.ID,
    coalesce(@userid,0), coalesce(@username,'SYSTEM'), 'update',
    showreg(NEW.classes, NEW.classes_v), showreg(NEW.server, NEW.server_v),
    showreg(NEW.sections, NEW.sections_v), showreg(NEW.teststeps, NEW.teststeps_v),
    showreg(NEW.details, NEW.details_v), showreg(NEW.units, NEW.units_v),
    concat('weekdays=', weekdaynames(NEW.weekdays), '\nmonthdayfrom=', NEW.mdaystart,
           '\nmonthdayto=', NEW.mdayend, '\ntimefrom=', NEW.starttime, '\ntimeto=',
           NEW.endtime, '\nremark=', quotenl(NEW.remark))
  from dual
  where NEW.TS != OLD.TS;
end//

drop trigger if exists clientsuspensions_ai//
create trigger clientsuspensions_ai after insert on clientsuspensions
  for each row 
begin
  insert into changeprot
    (domainID, accessID, changedtable, tableID, userID, username, action,
     classes, server, section, teststep, details, unit, newvalues)
  values
    (NEW.domainID, NEW.accessID, 'clientsuspensions', NEW.ID,
     coalesce(@userid,0), coalesce(@username,'SYSTEM'), 'insert',
     showreg(NEW.classes, NEW.classes_v), showreg(NEW.server, NEW.server_v),
     showreg(NEW.sections, NEW.sections_v), showreg(NEW.teststeps, NEW.teststeps_v),
     showreg(NEW.details, NEW.details_v), showreg(NEW.units, NEW.units_v),
     concat('weekdays=', weekdaynames(NEW.weekdays), '\nmonthdayfrom=', NEW.mdaystart,
            '\nmonthdayto=', NEW.mdayend, '\ntimefrom=', NEW.starttime, '\ntimeto=',
            NEW.endtime, '\nremark=', quotenl(NEW.remark)));
end//

drop trigger if exists clientsuspensions_bd//
create trigger clientsuspensions_bd before delete on clientsuspensions
  for each row 
begin
  insert into changeprot
    (domainID, accessID, changedtable, tableID, userID, username, action,
     classes, server, section, teststep, details, unit, newvalues)
  select OLD.domainID, OLD.accessID, 'clientsuspensions', OLD.ID,
    coalesce(@userid,0), coalesce(@username,'SYSTEM'), 'delete',
    showreg(OLD.classes, OLD.classes_v), showreg(OLD.server, OLD.server_v), showreg(OLD.sections, OLD.sections_v),
    showreg(OLD.teststeps, OLD.teststeps_v), showreg(OLD.details, OLD.details_v),
    showreg(OLD.units, OLD.units_v),
    coalesce(if(OLD.remark = @clientsuspensionremark, '', concat('remark=', quotenl(@clientsuspensionremark))),'');
end//

delimiter ;
