set @@character_set_client = 'utf8';

-- Testet vom Client angeforderte Ueberwachungspause
-- gesetzt sein muss: @domid, @srvname, @srvclass, @accid
-- Return: Datum/Zeit, bis zu der die Pause erlaubt ist oder
--         '0000-00-00 00:00:00' bei nicht erlaubt
--
-- Aufrufparameter
--   e: angeforderte Sektion
--   t: angeforderte Teststep
--   d: angeforderte Detail
--   u: angeforderte Unit
--   startdate: angeforderte Startzeit
--   enddate:   angeforderte Endezeit
--
-- Ergebnis
--   startdate: erlaubte Startzeit
--   enddate:   erlaubte Endezeit oder '0000-00-00 00:00:00', wenn nicht erlaubt 
--
-- Variablen
--   tes:  Initial: (e == '' ? '*' : e)
--   te:
--
--   ttts: (t == '' ? '*' : t)
--   tts:  noch nicht geprüfter Teil des ttts
--   tt:   zu prüfender Teil des tts, vor dem ertsen ','
--
--   ttds: (d == '' ? '*' : d)
--   tds:  noch nicht geprüfter Teil des ttds
--   td:   zu prüfender Teil des tds, vor dem ertsen ','
--
--   ttus: (u == '' ? '*' : u)
--   tus:  noch nicht geprüfter Teil des ttus
--   tu:   zu prüfender Teil des tus, vor dem ertsen ','


delimiter //

DROP PROCEDURE IF EXISTS test_clientsuspension//
create procedure test_clientsuspension(e varchar(500), t varchar(500), d varchar(500), u varchar(200),
                                       INOUT startdate datetime, INOUT enddate datetime)
  deterministic
  sql security invoker
  begin
    declare i integer;
    declare tes, te, ttts, tts, tt, ttds, tds, td varchar(500);
    declare ttus, tus, tu varchar(200);
    declare allowedstart, allowedend, newstartdate, newenddate datetime;

    set allowedstart = startdate;
    set allowedend = enddate;

    if e = '' then
      set tes = '*';
    else
      set tes = e;
    end if;
    if t = '' then
      set ttts = '*';
    else
      set ttts = t;
    end if;
    if d = '' then
      set ttds = '*';
    else
      set ttds = d;
    end if;
    if u = '' then
      set ttus = '*';
    else
      set ttus = u;
    end if;
    while tes != '' do
      set i = instr(tes, ',');
      if i = 0 then
        set te = tes;
        set tes = '';
      else
        set te = left(tes, i-1);
        set tes = substring(tes, i+1);
      end if;

      set tts = ttts;
      while tts != '' do
        set i = instr(tts, ',');
        if i = 0 then
          set tt = tts;
          set tts = '';
        else
          set tt = left(tts, i-1);
          set tts = substring(tts, i+1);
        end if;

        set tds = ttds;
        while tds != '' do
          set i = instr(tds, ',');
          if i = 0 then
            set td = tds;
            set tds = '';
          else
            set td = left(tds, i-1);
            set tds = substring(tds, i+1);
          end if;

          set tus = ttus;
          while tus != '' do
            set i = instr(tus, ',');
            if i = 0 then
              set tu = tus;
              set tus = '';
            else
              set tu = left(tus, i-1);
              set tus = substring(tus, i+1);
            end if;

            if (select count(*) from clientsuspensions
                where domainID = @domid and accessID = @accid
                  and testreg(@srvname, server, server_v) and testreg(@srvclass, classes, classes_v)
                  and testreg(te, sections, sections_v) and testreg(tt, teststeps, teststeps_v)
                  and testreg(td, details, details_v) and testreg(tu, units, units_v)
                  and starttime = '00:00:00' and endtime = '23:59:59'
                  and weekdays = '0,1,2,3,4,5,6' and mdaystart = 0 and mdayend = 32) = 0 then
              set newenddate = NULL;
              set newstartdate = NULL;
              select min(addtime(date(startdate), starttime)) as sd,
                  max(addtime(date(startdate), endtime + interval if(endtime < starttime, 24, 0) hour)) as ed
                from clientsuspensions
                where domainID = @domid and accessID = @accid
                  and testreg(@srvname, server, server_v) and testreg(@srvclass, classes, classes_v)
                  and testreg(te, sections, sections_v) and testreg(tt, teststeps, teststeps_v)
                  and testreg(td, details, details_v) and testreg(tu, units, units_v)
                  and find_in_set(weekday(startdate), weekdays)
                  and mdaystart <= day(startdate) and day(startdate) <= mdayend
                  and (starttime != '00:00:00' or endtime != '23:59:59'
                       or weekdays != '0,1,2,3,4,5,6' or mdaystart != 0 or mdayend != 32)
                into newstartdate, newenddate;

              if newenddate is NULL then
                set allowedend = '0000-00-00 00:00:00';
                set tus = '';
                set tds = '';
                set tts = '';
                set tes = '';
              else
                if newenddate < allowedend then
                  set allowedend = newenddate;
                end if;
                if newstartdate > allowedstart then
                  set allowedstart = newstartdate;
                end if;
              end if;
            end if;
          end while;
        end while;
      end while;
    end while;
    if allowedstart > allowedend then
      set enddate = '0000-00-00 00:00:00';
    else
      set startdate = allowedstart;
      set enddate = allowedend;
    end if;
  end//
