set @@character_set_client = 'utf8';

###############################################
# groupautos.sql
#
# Wird aufgerufen aus Admin-Menue, wenn einer
# Gruppe Verfahren hinzugefuegt werden oder
# einem Verfahren Gruppen hinzugefuegt werden
#
# Kombidetails werden in rogroupautos behandelt 
#
###############################################

delimiter //


--
-- loggingtmp.gwids anlegen
-- Alle Werteindizes aus den Verfahren "domids", die dem Muster entsprechen
--

DROP procedure IF EXISTS gwids//
create procedure gwids(domids varchar(20000), aid integer unsigned,
                   dom varchar(500), domv varchar(300),
                   cls varchar(200), clsv varchar(100), s varchar(500), sv varchar(300),
                   e varchar(500), ev varchar(300), t varchar(500), tv varchar(300),
                   d varchar(500), dv varchar(300), u varchar(200), uv varchar(100))
  deterministic
  sql security invoker
 begin

  create temporary table loggingtmp.srvids (primary key(ID))
    select distinct s.ID
    from verfahren as v
    join server as s on s.verfahrenID = v.ID
    left join serverclasses as sc on sc.ID = s.serverclassesID
    where find_in_set(v.ID, domids)
      and testreg(v.name, dom, domv) and testreg(s.servername, s, sv)
      and testreg(coalesce(sc.name, ''), cls, clsv);

  create temporary table loggingtmp.secids (primary key(ID))
    select ID from section
    where testreg(section.name, e, ev);

  create temporary table loggingtmp.tstids (primary key(ID))
    select ID from teststep
    where testreg(teststep.name, t, tv);

  create temporary table loggingtmp.detids (primary key(ID))
    select teststepdetails.ID, type as wtype
    from teststepdetails, einheiten
    where testreg(teststepdetails.name, d, dv) and einheitID = einheiten.ID
      and testreg(einheiten.name, u, uv);

  create temporary table loggingtmp.gwids (primary key(ID))
    select distinct werteindizes.ID, detids.wtype,
      serverID, sectionID, teststepID, teststepdetailsID, accessID
    from werteindizes, loggingtmp.detids
    where serverID in (select ID from loggingtmp.srvids)
      and sectionID in (select ID from loggingtmp.secids)
      and teststepID in (select ID from loggingtmp.tstids)
      and teststepdetailsID = detids.ID and werteindizes.accessid = aid;

  drop temporary table if exists loggingtmp.srvids, loggingtmp.secids,
    loggingtmp.tstids, loggingtmp.detids;

end//


DROP procedure IF EXISTS gcwids//
create procedure gcwids(domids varchar(20000), aid integer unsigned,
                   dom varchar(500), domv varchar(300),
                   cls varchar(200), clsv varchar(100), s varchar(500), sv varchar(300),
                   e varchar(500), ev varchar(300), t varchar(500), tv varchar(300),
                   d varchar(500), dv varchar(300), u varchar(200), uv varchar(100))
  deterministic
  sql security invoker
 begin

  create temporary table loggingtmp.srvids (primary key(ID))
    select distinct s.ID
    from verfahren as v
    join server as s on s.verfahrenID = v.ID
    left join serverclasses as sc on sc.ID = s.serverclassesID
    where find_in_set(v.ID, domids)
      and testreg(v.name, dom, domv) and testreg(s.servername, s, sv)
      and testreg(coalesce(sc.name, ''), cls, clsv);

  create temporary table loggingtmp.secids (primary key(ID))
    select ID from section
    where testreg(section.name, e, ev);

  create temporary table loggingtmp.tstids (primary key(ID))
    select ID from teststep
    where testreg(teststep.name, t, tv);

  create temporary table loggingtmp.ehids (primary key(ID))
    select ID from einheiten
    where testreg(einheiten.name, u, uv);

  create temporary table loggingtmp.gcwids (primary key(ID))
    select distinct lw.ID
    from lwerteindizes as lw
    join loggingtmp.srvids on srvids.ID = lw.serverID
    join loggingtmp.secids on secids.ID = lw.sectionID
    join loggingtmp.tstids on tstids.ID = lw.teststepID
    join teststepdetails as d on d.ID = lw.teststepdetailsID
    join loggingtmp.ehids on ehids.ID = d.einheitID
    join groupfunctions as gf on gf.ID = lw.groupfunctionsID
    where lw.accessID = aid
      and testreg(concat(gf.code, '[', left(period,1), '](', d.name, ')'), d, dv);

  drop temporary table if exists loggingtmp.srvids, loggingtmp.secids,
    loggingtmp.tstids, loggingtmp.ehids;

end//


DROP procedure IF EXISTS gsstids//
create procedure gsstids(domids varchar(20000), aid integer unsigned,
                   dom varchar(500), domv varchar(300),
                   cls varchar(200), clsv varchar(100), s varchar(500), sv varchar(300),
                   e varchar(500), ev varchar(300), t varchar(500), tv varchar(300),
                   d varchar(500))
  deterministic
  sql security invoker
 begin

  create temporary table loggingtmp.srvids (primary key(ID))
    select distinct s.ID
    from verfahren as v
    join server as s on s.verfahrenID = v.ID
    left join serverclasses as sc on sc.ID = s.serverclassesID
    where find_in_set(v.ID, domids)
      and testreg(v.name, dom, domv) and testreg(s.servername, s, sv)
      and testreg(coalesce(sc.name, ''), cls, clsv);

  create temporary table loggingtmp.secids (primary key(ID))
    select ID from section
    where testreg(section.name, e, ev);

  create temporary table loggingtmp.tstids (primary key(ID))
    select ID from teststep
    where testreg(teststep.name, t, tv);

  create temporary table loggingtmp.detids (primary key(ID))
    select teststepdetails.ID
    from teststepdetails
    where find_in_set(teststepdetails.name, d);

  create temporary table loggingtmp.gsstids (primary key(serverID,sectionID,teststepID))
    select distinct w.serverID, w.sectionID, w.teststepID
    from werteindizes as w
    where w.serverID in (select ID from loggingtmp.srvids)
      and w.sectionID in (select ID from loggingtmp.secids)
      and w.teststepID in (select ID from loggingtmp.tstids)
      and w.teststepdetailsID in (select ID from loggingtmp.detids)
      and w.accessID = aid;

  drop temporary table if exists loggingtmp.srvids, loggingtmp.secids,
    loggingtmp.tstids, loggingtmp.detids;

end//


DROP procedure IF EXISTS gcsstids//
create procedure gcsstids(domids varchar(20000), aid integer unsigned,
                   dom varchar(500), domv varchar(300), s varchar(500), sv varchar(300),
                   e varchar(500), ev varchar(300), t varchar(500), tv varchar(300),
                   d varchar(500))
  deterministic
  sql security invoker
 begin

  create temporary table loggingtmp.srvids (primary key(ID))
    select distinct ID
    from server as s
    where find_in_set(s.verfahrenID, domids)
      and testreg(s.servername, s, sv);

  create temporary table loggingtmp.secids (primary key(ID))
    select ID from section
    where testreg(section.name, e, ev);

  create temporary table loggingtmp.tstids (primary key(ID))
    select ID from teststep
    where testreg(teststep.name, t, tv);

  create temporary table loggingtmp.gcsstids (primary key(serverID,sectionID,teststepID))
    select distinct lw.serverID, lw.sectionID, lw.teststepID
    from lwerteindizes as lw
    join loggingtmp.srvids on srvids.ID = lw.serverID
    join loggingtmp.secids on secids.ID = lw.sectionID
    join loggingtmp.tstids on tstids.ID = lw.teststepID
    join teststepdetails as d on d.ID = lw.teststepdetailsID
    join groupfunctions as gf on gf.ID = lw.groupfunctionsID
    where find_in_set(concat(gf.code, '[', left(period, 1), '](', d.name, ')'), d);

  drop temporary table if exists loggingtmp.srvids, loggingtmp.secids,
    loggingtmp.tstids;

end//


DROP procedure IF EXISTS groupautos//
create procedure groupautos(groupids varchar(20000), domids varchar(20000),
                            aid integer unsigned)
  deterministic
  sql security invoker
 begin
  declare dom, s, e, t, d varchar(500);
  declare domv, sv, ev, tv, dv varchar(300);
  declare cls, u varchar(200);
  declare clsv, uv varchar(100);
  declare q, fkt varchar(10000);
  declare cnstvars, uwids varchar(3000);
  declare si, ci, ti, gaid, slaveid, fdwid, z integer unsigned;
  declare ctype enum('num','str','dat','blob');
  declare hids, dids, wids, mids varchar(100);
  declare spids varchar(30);
  declare glimcur cursor for
    select ID, mg.slavegroupID, domain, domain_v, classes, classes_v, server, server_v, section, section_v,
      teststep, teststep_v, details, details_v, einheit, einheit_v
    from gautolimits as gal
    left join masterslavegroups as mg on mg.mastergroupID = gal.groupID
    where accessID = aid and find_in_set(coalesce(mg.slavegroupID, gal.groupID), groupids);
  declare gisacur cursor for
    select ID, mg.slavegroupID, domain, domain_v, classes, classes_v, server, server_v, section, section_v,
      teststep, teststep_v, details, details_v, einheit, einheit_v
    from gautoisalive as gai
    left join masterslavegroups as mg on mg.mastergroupID = gai.groupID
    where accessID = aid and find_in_set(coalesce(mg.slavegroupID, gai.groupID), groupids);
  declare gcmblimcur cursor for
    select ID, mg.slavegroupID, domain, domain_v, classes, classes_v, server, server_v, section, section_v,
      teststep, teststep_v, details, expression
    from gautocombilimits as gac
    left join masterslavegroups as mg on mg.mastergroupID = gac.groupID
    where accessID = aid and find_in_set(coalesce(mg.slavegroupID, gac.groupID), groupids);
  declare gsstcur cursor for
    select serverID, sectionID, teststepID
    from loggingtmp.gsstids;
  declare gcsstcur cursor for
    select serverID, sectionID, teststepID
    from loggingtmp.gcsstids;
  declare gcmplimcur cursor for
    select ID, mg.slavegroupID, domain, domain_v, classes, classes_v, server, server_v, section, section_v,
      teststep, teststep_v, details, details_v, einheit, einheit_v
    from gautoclimits as gacl
    left join masterslavegroups as mg on mg.mastergroupID = gacl.groupID
    where accessID = aid and find_in_set(coalesce(mg.slavegroupID, gacl.groupID), groupids);
  declare gcomprcur cursor for
    select ID, mg.slavegroupID, domain, domain_v, server, server_v, section, section_v,
      teststep, teststep_v, details, details_v, einheit, einheit_v,
      hourIDs, dayIDs, weekIDs, monthIDs, specialIDs
    from gautocompression
    left join masterslavegroups as mg on mg.mastergroupID = gautocompression.groupID
    where aktiv = '1' and accessID = aid and find_in_set(groupID, groupids);
  declare continue handler for not found set z = 1;


-- Limits

  create temporary table loggingtmp.wids (
    ID integer unsigned not null default '0',
    primary key(ID));
  set z = 0;
  open glimcur;
  fetch glimcur into gaid, slaveid, dom, domv, cls, clsv, s, sv, e, ev, t, tv, d, dv, u, uv;
  while z != 1 do
    call gwids(domids, aid, dom, domv, cls, clsv, s, sv, e, ev, t, tv, d, dv, u, uv);
    delete loggingtmp.gwids from loggingtmp.gwids
      join wertelimits
        on wertelimits.groupautoID = gaid and wertelimits.slavegroupID <=> slaveid
          and wertelimits.werteindizesID = gwids.ID;
    insert into wertelimits
      (werteindizesID, slavegroupID, groupautoID, infowert, warnwert, errorwert, exclude, vergleich,
       groupfunctionsID, anzmittel, meldung, meldungszielID, ziel1level,
       meldungsziel2ID, ziel2level, notifymode, bemerkungen)
      select gwids.ID, slaveid, gaid, ga.infowert, ga.warnwert, ga.errorwert, ga.exclude, ga.vergleich,
        ga.groupfunctionsID, ga.anzmittel, ga.meldung, ga.meldungszielID, ga.ziel1level,
        ga.meldungsziel2ID, ga.ziel2level, ga.notifymode, ga.bemerkungen
      from gautolimits as ga
      join groupfunctions on groupfunctions.ID = ga.groupfunctionsID
      join loggingtmp.gwids
      where ga.ID = gaid
        and if(ga.notifymode like 'S%', find_in_set('str',flags) AND wtype = 'str',
               find_in_set(wtype,flags));
    insert ignore into loggingtmp.wids select ID from loggingtmp.gwids;
    drop temporary table loggingtmp.gwids;
    fetch glimcur into gaid, slaveid, dom, domv, cls, clsv, s, sv, e, ev, t, tv, d, dv, u, uv;
  end while;
  close glimcur;

  create temporary table loggingtmp.ano (primary key(ID))
    select wids.ID, min(ga.nootherflag) as mnoflg
    from loggingtmp.wids
    join wertelimits as l on l.werteindizesID = wids.ID
    join gautolimits as ga on ga.ID = l.groupautoID
    group by wids.ID;
  update wertelimits as l
    join gautolimits as ga on ga.ID = l.groupautoID and ga.nootherflag
    join loggingtmp.ano on ano.ID = l.werteindizesID
    set l.hidden = not mnoflg;
  drop temporary table loggingtmp.ano;


-- isAlive

  delete from loggingtmp.wids;
  set z = 0;
  open gisacur;
  fetch gisacur into gaid, slaveid, dom, domv, cls, clsv, s, sv, e, ev, t, tv, d, dv, u, uv;
  while z != 1 do
    call gwids(domids, aid, dom, domv, cls, clsv, s, sv, e, ev, t, tv, d, dv, u, uv);
    delete loggingtmp.gwids from loggingtmp.gwids
      join isalive
        on isalive.groupautoID = gaid and isalive.slavegroupID <=> slaveid
          and isalive.werteindizesID = gwids.ID;
    insert into isalive
      (werteindizesID, slavegroupID, groupautoID, maxperiods, intervalleID, meldung, meldungszielID,
       meldungsziel2ID, notifymode, bemerkungen, autoclose, msglevel)
      select gwids.ID, slaveid, gaid, ga.maxperiods, ga.intervalleID, ga.meldung, ga.meldungszielID,
        ga.meldungsziel2ID, ga.notifymode, ga.bemerkungen, ga.autoclose, ga.msglevel
      from gautoisalive as ga, loggingtmp.gwids
      where ga.ID = gaid;
    insert ignore into loggingtmp.wids select ID from loggingtmp.gwids;
    drop temporary table loggingtmp.gwids;
    fetch gisacur into gaid, slaveid, dom, domv, cls, clsv, s, sv, e, ev, t, tv, d, dv, u, uv;
  end while;
  close gisacur;

  create temporary table loggingtmp.ano (primary key(ID))
    select wids.ID, min(ga.nootherflag) as mnoflg
    from loggingtmp.wids
    join isalive as i on i.werteindizesID = wids.ID
    join gautoisalive as ga on ga.ID = i.groupautoID
    group by wids.ID;
  update isalive as i
    join gautoisalive as ga on ga.ID = i.groupautoID and ga.nootherflag
    join loggingtmp.ano on ano.ID = i.werteindizesID
    set i.hidden = not mnoflg;
  drop temporary table loggingtmp.ano;


-- Kombilimits

  create temporary table loggingtmp.sstids (
    serverID integer unsigned not null default '0',
    sectionID integer unsigned not null default '0',
    teststepID integer unsigned not null default '0',
    accessID integer unsigned not null default '0',
    primary key(serverID, sectionID, teststepID, accessID));
  open gcmblimcur;
  set z = 0;
  fetch gcmblimcur into gaid, slaveid, dom, domv, cls, clsv, s, sv, e, ev, t, tv, d, fkt;
  while z != 1 do
    call gsstids(domids, aid, dom, domv, cls, clsv, s, sv, e, ev, t, tv, d);
    delete loggingtmp.gsstids from loggingtmp.gsstids
      join kombilimits as kl
        on kl.groupautoID = gaid and kl.slavegroupID <=> slaveid and kl.serverID = gsstids.serverID
          and kl.sectionID = gsstids.sectionID and kl.teststepID = gsstids.teststepID;
    open gsstcur;
    set z = 0;
    fetch gsstcur into si, ci, ti;
    while z != 1 do
      call convert_combi(si, ci, ti, aid, fkt, '', '', q, fdwid, ctype, cnstvars, uwids);
      if q != '' then
        insert into kombilimits
          (serverID, sectionID, teststepID, expression, expressionsql, relation, infolevel,
           warnlevel, errorlevel, notifymode, meldung, meldungszielID, dest1level,
           meldungsziel2ID, dest2level, aktiv, slavegroupID, groupautoID, bemerkungen, accessID, usedwIDs)
          select si, ci, ti, expression, concat('select ', q), relation, infolevel,
            warnlevel, errorlevel, notifymode, meldung, meldungszielID, dest1level,
            meldungsziel2ID, dest2level, aktiv, slaveid, ID, bemerkungen, aid, trim(leading ',' from uwids)
          from gautocombilimits
          where ID = gaid;
      end if;
      fetch gsstcur into si, ci, ti;
    end while;
    close gsstcur;

    insert ignore into loggingtmp.sstids (serverID, sectionID, teststepID, accessID)
      select serverID, sectionID, teststepID, aid  from loggingtmp.gsstids;
    drop temporary table loggingtmp.gsstids;
    set z = 0;
    fetch gcmblimcur into gaid, slaveid, dom, domv, cls, clsv, s, sv, e, ev, t, tv, d, fkt;
  end while;
  close gcmblimcur;


  create temporary table loggingtmp.ano (primary key(serverID, sectionID, teststepID, accessID))
    select sstids.serverID, sstids.sectionID, sstids.teststepID, sstids.accessID,
      min(ga.nootherflag) as mnoflg
    from loggingtmp.sstids
    join kombilimits as k
      on k.serverID = sstids.serverID and k.sectionID = sstids.sectionID
        and k.teststepID = sstids.teststepID and k.accessID = sstids.accessID
    join gautocombilimits as ga on ga.ID = k.groupautoID
    group by sstids.serverID, sstids.sectionID, sstids.teststepID, sstids.accessID;
  update kombilimits as k
    join gautocombilimits as ga on ga.ID = k.groupautoID and ga.nootherflag
    join loggingtmp.ano
      on k.serverID = ano.serverID and k.sectionID = ano.sectionID
        and k.teststepID = ano.teststepID and k.accessID = ano.accessID
    set k.hidden = not mnoflg;
  drop temporary table loggingtmp.ano, loggingtmp.sstids;


-- Group-Autokomprimierung

  create temporary table loggingtmp.tgcwids (
    lwID integer unsigned not null default '0',
    primary key (lwID));
  set z = 0;
  open gcomprcur;
  fetch gcomprcur into gaid, slaveid, dom, domv, s, sv, e, ev, t, tv, d, dv, u, uv,
    hids, dids, wids, mids, spids;
  while z != 1 do
    call gwids(domids, aid, dom, domv, '.*', '', s, sv, e, ev, t, tv, d, dv, u, uv);
    if hids != '' then
      insert ignore into lwerteindizes
        (serverID, sectionID, teststepID, teststepdetailsID, accessID,
         groupfunctionsID, period)
        select serverID, sectionID, teststepID, teststepdetailsID, accessID,
          groupfunctions.ID, 'Hour'
        from loggingtmp.gwids
        join groupfunctions
          on find_in_set(groupfunctions.ID, hids) and find_in_set(gwids.wtype, aggregationtypes);
      insert ignore into komprimierungids (groupautoID, lwerteindizesID, slavegroupID)
        select gaid, lwerteindizes.ID, slaveid
        from lwerteindizes
        join loggingtmp.gwids
          using(serverID, sectionID, teststepID, teststepdetailsID, accessID)
        where find_in_set(groupfunctionsID, hids) and period = 'Hour';
      insert ignore into loggingtmp.tgcwids (lwID)
        select lwerteindizes.ID
        from lwerteindizes
        join loggingtmp.gwids
          using(serverID, sectionID, teststepID, teststepdetailsID, accessID)
        where find_in_set(groupfunctionsID, hids) and period = 'Hour';
    end if;
    if dids != '' then
      insert ignore into lwerteindizes
        (serverID, sectionID, teststepID, teststepdetailsID, accessID,
         groupfunctionsID, period)
        select serverID, sectionID, teststepID, teststepdetailsID, accessID,
          groupfunctions.ID, 'Day'
        from loggingtmp.gwids
        join groupfunctions
          on find_in_set(groupfunctions.ID, dids) and find_in_set(gwids.wtype, aggregationtypes);
      insert ignore into komprimierungids (groupautoID, lwerteindizesID, slavegroupID)
        select gaid, lwerteindizes.ID, slaveid
        from lwerteindizes
        join loggingtmp.gwids
          using(serverID, sectionID, teststepID, teststepdetailsID, accessID)
        where find_in_set(groupfunctionsID, dids) and period = 'Day';
      insert ignore into loggingtmp.tgcwids (lwID)
        select lwerteindizes.ID
        from lwerteindizes
        join loggingtmp.gwids
          using(serverID, sectionID, teststepID, teststepdetailsID, accessID)
        where find_in_set(groupfunctionsID, dids) and period = 'Day';
    end if;
    if wids != '' then
      insert ignore into lwerteindizes
        (serverID, sectionID, teststepID, teststepdetailsID, accessID,
         groupfunctionsID, period)
        select serverID, sectionID, teststepID, teststepdetailsID, accessID,
          groupfunctions.ID, 'Week'
        from loggingtmp.gwids
        join groupfunctions
          on find_in_set(groupfunctions.ID, wids) and find_in_set(gwids.wtype, aggregationtypes);
      insert ignore into komprimierungids (groupautoID, lwerteindizesID, slavegroupID)
        select gaid, lwerteindizes.ID, slaveid
        from lwerteindizes
        join loggingtmp.gwids
          using(serverID, sectionID, teststepID, teststepdetailsID, accessID)
        where find_in_set(groupfunctionsID, wids) and period = 'Week';
      insert ignore into loggingtmp.tgcwids (lwID)
        select lwerteindizes.ID
        from lwerteindizes
        join loggingtmp.gwids
          using(serverID, sectionID, teststepID, teststepdetailsID, accessID)
        where find_in_set(groupfunctionsID, wids) and period = 'Week';
    end if;
    if mids != '' then
      insert ignore into lwerteindizes
        (serverID, sectionID, teststepID, teststepdetailsID, accessID,
         groupfunctionsID, period)
        select serverID, sectionID, teststepID, teststepdetailsID, accessID,
          groupfunctions.ID, 'Month'
        from loggingtmp.gwids
        join groupfunctions
          on find_in_set(groupfunctions.ID, mids) and find_in_set(gwids.wtype, aggregationtypes);
      insert ignore into komprimierungids (groupautoID, lwerteindizesID, slavegroupID)
        select gaid, lwerteindizes.ID, slaveid
        from lwerteindizes
        join loggingtmp.gwids
          using(serverID, sectionID, teststepID, teststepdetailsID, accessID)
        where find_in_set(groupfunctionsID, mids) and period = 'Month';
      insert ignore into loggingtmp.tgcwids (lwID)
        select lwerteindizes.ID
        from lwerteindizes
        join loggingtmp.gwids
          using(serverID, sectionID, teststepID, teststepdetailsID, accessID)
        where find_in_set(groupfunctionsID, mids) and period = 'Month';
    end if;
    if spids != '' then
      insert ignore into lwerteindizes
        (serverID, sectionID, teststepID, teststepdetailsID, accessID,
         groupfunctionsID, period)
        select serverID, sectionID, teststepID, teststepdetailsID, accessID,
          groupfunctions.ID, 'special'
        from loggingtmp.gwids
        join groupfunctions
          on find_in_set(groupfunctions.ID, spids) and find_in_set(gwids.wtype, aggregationspecialtypes);
      insert ignore into komprimierungids (groupautoID, lwerteindizesID, slavegroupID)
        select gaid, lwerteindizes.ID, slaveid
        from lwerteindizes
        join loggingtmp.gwids
          using(serverID, sectionID, teststepID, teststepdetailsID, accessID)
        where find_in_set(groupfunctionsID, spids) and period = 'special';
      insert ignore into loggingtmp.tgcwids (lwID)
        select lwerteindizes.ID
          from lwerteindizes
        join loggingtmp.gwids
          using(serverID, sectionID, teststepID, teststepdetailsID, accessID)
        where find_in_set(groupfunctionsID, spids) and period = 'special';
    end if;
    drop temporary table loggingtmp.gwids;
    fetch gcomprcur into gaid, slaveid, dom, domv, s, sv, e, ev, t, tv, d, dv, u, uv,
      hids, dids, wids, mids, spids;
  end while;
  close gcomprcur;

  drop temporary table loggingtmp.tgcwids;


-- kompr. Limits - erst nach dem Anlegen neuer lwerteindizes

  delete from loggingtmp.wids;
  set z = 0;
  open gcmplimcur;
  fetch gcmplimcur into gaid, slaveid, dom, domv, cls, clsv, s, sv, e, ev, t, tv, d, dv, u, uv;
  while z != 1 do
    call gcwids(domids, aid, dom, domv, cls, clsv, s, sv, e, ev, t, tv, d, dv, u, uv);
    delete loggingtmp.gcwids from loggingtmp.gcwids
      join lwertelimits
        on lwertelimits.groupautoID = gaid and lwertelimits.slavegroupID <=> slaveid
          and lwertelimits.lwerteindizesID = gcwids.ID;
    insert into lwertelimits
      (lwerteindizesID, slavegroupID, groupautoID, infowert, warnwert, errorwert, vergleich,
       groupfunctionsID, anzmittel, meldung, meldungszielID, ziel1level,
       meldungsziel2ID, ziel2level, bemerkungen)
      select gcwids.ID, slaveid, gaid, infowert, warnwert, errorwert, vergleich,
        groupfunctionsID, anzmittel, meldung, meldungszielID, ziel1level,
        meldungsziel2ID, ziel2level, bemerkungen
      from gautoclimits as ga, loggingtmp.gcwids
      where ga.ID = gaid;
    insert ignore into loggingtmp.wids select ID from loggingtmp.gcwids;
    drop temporary table loggingtmp.gcwids;
    fetch gcmplimcur into gaid, slaveid, dom, domv, cls, clsv, s, sv, e, ev, t, tv, d, dv, u, uv;
  end while;
  close gcmplimcur;

  create temporary table loggingtmp.ano (primary key(ID))
    select wids.ID, min(ga.nootherflag) as mnoflg
    from loggingtmp.wids
    join lwertelimits as l on l.lwerteindizesID = wids.ID
    join gautoclimits as ga on ga.ID = l.groupautoID
    group by wids.ID;
  update lwertelimits as l
    join loggingtmp.ano on ano.ID = l.lwerteindizesID
    join gautoclimits as ga on ga.ID = l.groupautoID and ga.nootherflag
    set l.hidden = not mnoflg;
  drop temporary table loggingtmp.ano, loggingtmp.wids;


end//
