set @@character_set_client = 'utf8';

##################################
# limgrpstat.sql
#
# Status-Tabellen der Limitgruppen updaten
#
# Bedeutung level:
#  0: new
#  1: none
#  2: preinfo
#  3: suspended
#  4-6: info - error
#############################################################

delimiter //

DROP procedure IF EXISTS limgrpstat//
create procedure limgrpstat(limgrpid integer unsigned)
  deterministic
  sql security invoker
 begin

  declare z integer;

  if not exists (select * from limgrpstat where limgrpstat.limitgroupID = limgrpid) then
    insert ignore into limgrpstat (limitgroupID, workerid, TS) values (limgrpid, CONNECTION_ID(), UTC_TIMESTAMP());
  else
    update limgrpstat set workerid = CONNECTION_ID(), TS = UTC_TIMESTAMP()
      where limitgroupID = limgrpid
        and ((workerid = 0 AND UTC_TIMESTAMP() > TS + interval 2 minute) OR UTC_TIMESTAMP() > TS + interval 3 minute);
  end if;

  if (select workerid from limgrpstat where limgrpstat.limitgroupID = limgrpid) = CONNECTION_ID() then

    create temporary table loggingtmp.newlimgrpstats (primary key(verfahrenID, classID))
      select v.ID as verfahrenID, c.ID as classID, 0 as level, now() as grptestdate
      from limitgroup
      join gruppenrechte as gr on gr.gruppenID = limitgroup.groupID and gr.accessID = 1 and gr.admin = '1'
      join verfahren as v on v.ID = gr.verfahrenID and testreg(v.name, domain, domain_v)
      join serverclasses as c
      where limitgroup.ID = limgrpid;

    create temporary table loggingtmp.newlimgrpelemstats
        (primary key limgrpelemID(limgrpelemID, verfahrenID, classID))
      select limgrpelemID, verfahrenID, classID,
        case when mingood > 0 then
          case when nok >= mingood then if(warngood > 0 AND nok < warngood, 2, 1)
               when nok+suspensions >= mingood then 3
               when nok+suspensions+nil >= mingood then 4
               when nok+suspensions+nil+nwl >= mingood then 5
               else 6 end
        when nel > 0 then 6
        when nwl > 0 then 5
        when nil > 0 then 4
        when suspensions > 0 then 3
        when nok > 0 then 1
        else 0 end as level, lasttestdate
      from
      ( select lge.ID as limgrpelemID, nlgs.verfahrenID, nlgs.classID, lge.mingood, lge.warngood,
          sum(up.verfahrenID is NULL and twl.msglevel = 'none') as nok,
          sum(up.verfahrenID is NULL and twl.msglevel = 'info') as nil,
          sum(up.verfahrenID is NULL and twl.msglevel = 'warn') as nwl,
          sum(up.verfahrenID is NULL and twl.msglevel = 'error') as nel,
          sum(up.verfahrenID is not NULL) as suspensions,
          max(lasttestdate) as lasttestdate
        from loggingtmp.newlimgrpstats as nlgs
        join limitgroupelement as lge on limitgroupID = limgrpid and limtype = 'L'
        join gautolimits as ga on ga.ID = lge.groupautoID and ga.aktiv = '1'
        join wertelimits as wl on wl.groupautoID = ga.ID and wl.aktiv = '1'
        join twertelimits as twl on twl.ID = wl.ID
        join werteindizes as w on w.ID = wl.werteindizesID
        join server as s
          on s.verfahrenID = nlgs.verfahrenID and s.serverclassesID = nlgs.classID
            and s.ID = w.serverID and s.state = 'active'
            and testreg(s.servername, lge.server, lge.server_v)
        join serverclasses as c on c.ID = serverclassesID and testreg(c.name, lge.classes, lge.classes_v)
        join verfahren as v on v.ID = s.verfahrenID and testreg(v.name, lge.domain, lge.domain_v)
        join section as e on e.ID = w.sectionID and testreg(e.name, lge.section, lge.section_v)
        join teststep as t on t.ID = w.teststepID and testreg(t.name, lge.teststep, lge.teststep_v)
        join teststepdetails as d on d.ID = teststepdetailsID
        join einheiten as u on u.ID = einheitID
        left join ueberwachungspausen as up
          on up.verfahrenID = s.verfahrenID and up.accessID = w.accessID
            and testreg(c.name, up.classes, up.classes_v)
            and testreg(s.servername, up.server, up.server_v)
            and testreg(e.name, up.section, up.section_v)
            and testreg(t.name, up.teststep, up.teststep_v)
            and testreg(d.name, up.details, up.details_v)
            and testreg(u.name, up.einheit, up.einheit_v)
            and datumvon <= now() and now() <= datumbis
            and find_in_set(weekday(curdate()), weekdays)
            and zeitvon <= curtime() and curtime() <= zeitbis
            and if(mdaystart >= 0, mdaystart <= day(curdate()),
                   month(curdate()) < month(curdate() + interval mdaystart day))
            and if(mdayend >= 0, day(curdate()) <= mdayend,
                   month(curdate()) = month(curdate() + interval mdayend day))
        group by limgrpelemID, verfahrenID, classID) as n;

    insert into loggingtmp.newlimgrpelemstats (limgrpelemID, verfahrenID, classID, level, lasttestdate)
      select limgrpelemID, verfahrenID, classID,
        case when mingood > 0 then
          case when nok >= mingood then if(warngood > 0 AND nok < warngood, 2, 1)
               when nok+suspensions >= mingood then 3
               when nok+suspensions+nil >= mingood then 4
               when nok+suspensions+nil+nwl >= mingood then 5
               else 6 end
        when nel > 0 then 6
        when nwl > 0 then 5
        when nil > 0 then 4
        when suspensions > 0 then 3
        when nok > 0 then 1
        else 0 end as level, lasttestdate
      from
      ( select lge.ID as limgrpelemID, nlgs.verfahrenID, nlgs.classID, lge.mingood, lge.warngood,
          sum(up.verfahrenID is NULL and tcmbl.msglevel = 'none') as nok,
          sum(up.verfahrenID is NULL and tcmbl.msglevel = 'info') as nil,
          sum(up.verfahrenID is NULL and tcmbl.msglevel = 'warn') as nwl,
          sum(up.verfahrenID is NULL and tcmbl.msglevel = 'error') as nel,
          sum(up.verfahrenID is not NULL) as suspensions,
          max(lasttestdate) as lasttestdate
        from loggingtmp.newlimgrpstats as nlgs
        join limitgroupelement as lge on limitgroupID = limgrpid and limtype = 'C'
        join gautocombilimits as ga on ga.ID = lge.groupautoID
        join kombilimits as cmbl on cmbl.groupautoID = ga.ID
        join tkombilimits as tcmbl on tcmbl.ID = cmbl.ID
        join server as s
          on s.verfahrenID = nlgs.verfahrenID and s.serverclassesID = nlgs.classID
            and s.ID = cmbl.serverID and s.state = 'active'
            and testreg(s.servername, lge.server, lge.server_v)
        join serverclasses as c on c.ID = serverclassesID and testreg(c.name, lge.classes, lge.classes_v)
        join verfahren as v on v.ID = s.verfahrenID and testreg(v.name, lge.domain, lge.domain_v)
        join section as e on e.ID = cmbl.sectionID and testreg(e.name, lge.section, lge.section_v)
        join teststep as t on t.ID = cmbl.teststepID and testreg(t.name, lge.teststep, lge.teststep_v)
        left join ueberwachungspausen as up
          on up.verfahrenID = s.verfahrenID and up.accessID = cmbl.accessID
            and testreg(c.name, up.classes, up.classes_v)
            and testreg(s.servername, up.server, up.server_v)
            and testreg(e.name, up.section, up.section_v)
            and testreg(t.name, up.teststep, up.teststep_v)
            and datumvon <= now() and now() <= datumbis
            and find_in_set(weekday(curdate()), weekdays)
            and zeitvon <= curtime() and curtime() <= zeitbis
            and if(mdaystart >= 0, mdaystart <= day(curdate()),
                   month(curdate()) < month(curdate() + interval mdaystart day))
            and if(mdayend >= 0, day(curdate()) <= mdayend,
                   month(curdate()) = month(curdate() + interval mdayend day))
        group by limgrpelemID, verfahrenID, classID) as n;

    insert into loggingtmp.newlimgrpelemstats (limgrpelemID, verfahrenID, classID, level, lasttestdate)
      select limgrpelemID, verfahrenID, classID,
        case when mingood > 0 then
          case when nok >= mingood then if(warngood > 0 AND nok < warngood, 2, 1)
               when nok+suspensions >= mingood then 3
               when nok+suspensions+nil >= mingood then 4
               when nok+suspensions+nil+nwl >= mingood then 5
               else 6 end
        when nel > 0 then 6
        when nwl > 0 then 5
        when nil > 0 then 4
        when suspensions > 0 then 3
        else 1 end as level, lasttestdate
      from
      ( select lge.ID as limgrpelemID, nlgs.verfahrenID, nlgs.classID, lge.mingood, lge.warngood,
          sum(up.verfahrenID is NULL and il.msglevel = 'none' and msgdate > lastdatum) as nok,
          sum(up.verfahrenID is NULL and il.msglevel = 'info' and msgdate > lastdatum) as nil,
          sum(up.verfahrenID is NULL and il.msglevel = 'warn' and msgdate > lastdatum) as nwl,
          sum(up.verfahrenID is NULL and il.msglevel = 'error' and msgdate > lastdatum) as nel,
          sum(up.verfahrenID is not NULL) as suspensions, max(lastdatum) as lasttestdate
        from loggingtmp.newlimgrpstats as nlgs
        join limitgroupelement as lge on limitgroupID = limgrpid and limtype = 'I'
        join gautoisalive as ga on ga.ID = lge.groupautoID and ga.aktiv = '1'
        join isalive as il on il.groupautoID = ga.ID and il.aktiv = '1'
        join tisalive as til on til.ID = il.ID
        join werteindizes as w on w.ID = il.werteindizesID
        join letztewerte as lw on lw.ID = w.ID
        join server as s
          on s.verfahrenID = nlgs.verfahrenID and s.serverclassesID = nlgs.classID
            and s.ID = w.serverID and s.state = 'active'
            and testreg(s.servername, lge.server, lge.server_v)
        join serverclasses as c on c.ID = serverclassesID and testreg(c.name, lge.classes, lge.classes_v)
        join verfahren as v on v.ID = s.verfahrenID and testreg(v.name, lge.domain, lge.domain_v)
        join section as e on e.ID = w.sectionID and testreg(e.name, lge.section, lge.section_v)
        join teststep as t on t.ID = w.teststepID and testreg(t.name, lge.teststep, lge.teststep_v)
        join teststepdetails as d on d.ID = teststepdetailsID
        join einheiten as u on u.ID = einheitID
        left join ueberwachungspausen as up
          on up.verfahrenID = s.verfahrenID and up.accessID = w.accessID
            and testreg(c.name, up.classes, up.classes_v)
            and testreg(s.servername, up.server, up.server_v)
            and testreg(e.name, up.section, up.section_v)
            and testreg(t.name, up.teststep, up.teststep_v)
            and testreg(d.name, up.details, up.details_v)
            and testreg(u.name, up.einheit, up.einheit_v)
            and datumvon <= now() and now() <= datumbis
            and find_in_set(weekday(curdate()), weekdays)
            and zeitvon <= curtime() and curtime() <= zeitbis
            and if(mdaystart >= 0, mdaystart <= day(curdate()),
                   month(curdate()) < month(curdate() + interval mdaystart day))
            and if(mdayend >= 0, day(curdate()) <= mdayend,
                   month(curdate()) = month(curdate() + interval mdayend day))
        group by limgrpelemID, verfahrenID, classID) as n;
    
    delete limgrpelemstats
      from limgrpelemstats
      left join loggingtmp.newlimgrpelemstats as n
        on n.limgrpelemID = limgrpelemstats.limgrpelemID
          and n.verfahrenID = limgrpelemstats.verfahrenID and n.classID = limgrpelemstats.classID
      where limgrpelemstats.limitgroupID = limgrpid and n.limgrpelemID is NULL;
    update limgrpelemstats as lg
      join loggingtmp.newlimgrpelemstats as n
        on n.limgrpelemID = lg.limgrpelemID
          and n.verfahrenID = lg.verfahrenID and n.classID = lg.classID
      set lg.level = n.level, lg.lasttestdate = n.lasttestdate
      where lg.limitgroupID = limgrpid;
    insert into limgrpelemstats (limitgroupID, limgrpelemID, verfahrenID, classID, level, lasttestdate)
      select limgrpid, n.limgrpelemID, n.verfahrenID, n.classID, n.level, n.lasttestdate
      from loggingtmp.newlimgrpelemstats as n
      left join limgrpelemstats as lg
        on lg.limgrpelemID = n.limgrpelemID
          and lg.verfahrenID = n.verfahrenID and lg.classID = n.classID
      where lg.limitgroupID is NULL;

    delete loggingtmp.newlimgrpstats
    from loggingtmp.newlimgrpstats
    left join (select distinct verfahrenID, classID
               from loggingtmp.newlimgrpelemstats) as n
      using (verfahrenID, classID)
    where n.verfahrenID is NULL;

    delete limgrpstats
      from limgrpstats
      left join loggingtmp.newlimgrpstats using(verfahrenID, classID)
      where limgrpstats.limitgroupID = limgrpid and newlimgrpstats.verfahrenID is NULL;
    update loggingtmp.newlimgrpstats
      join (select verfahrenID, classID, max(level) as level, max(lasttestdate) as lasttestdate
            from loggingtmp.newlimgrpelemstats
            group by verfahrenID, classID) as ml
        using(verfahrenID, classID)
      set newlimgrpstats.level = ml.level, newlimgrpstats.grptestdate = ml.lasttestdate;
    update limgrpstats
      join loggingtmp.newlimgrpstats as n using(verfahrenID, classID)
      set limgrpstats.level = n.level, limgrpstats.lasttestdate = n.grptestdate
      where limgrpstats.limitgroupID = limgrpid;
    insert into limgrpstats (limitgroupID, verfahrenID, classID, level, lasttestdate)
      select limgrpid, n.verfahrenID, n.classID, n.level, n.grptestdate
      from loggingtmp.newlimgrpstats as n
      left join limgrpstats as lg
        on lg.limitgroupID = limgrpid and lg.verfahrenID = n.verfahrenID and lg.classID = n.classID
      where lg.verfahrenID is NULL;

    drop temporary table loggingtmp.newlimgrpstats, loggingtmp.newlimgrpelemstats;

    update limgrpstat set workerid = 0, TS = UTC_TIMESTAMP()
      where limgrpstat.limitgroupID = limgrpid and workerid = CONNECTION_ID();
  else
    if (select workerid from limgrpstat where limitgroupID = limgrpid) > 0 then
      select sleep(3) into @dummy;
      if (select workerid from limgrpstat where limitgroupID = limgrpid) > 0 then
        select sleep(4) into @dummy;
        if (select workerid from limgrpstat where limitgroupID = limgrpid) > 0 then
          select sleep(6) into @dummy;
        end if;
      end if;
    end if;
  end if;
end//
