set @@character_set_client = 'utf8';

################################################
# newautos.sql
#
# Nach Anlegen eines neuen Werteindizes folgende
# Autos prüfen:
#  - autolimits, gautolimits
#  - autoisalive, gautoisalive
#  - autokombilimits, gautocombilimits
#  - autokombidetails, gautocombidetails
#  - autoccdetails, gautoccetails
################################################

delimiter //

DROP procedure IF EXISTS newautos//
create procedure newautos(wi integer unsigned, si integer unsigned, ei integer unsigned,
                          ti integer, di integer unsigned, aid integer unsigned)
  deterministic
  sql security invoker
 begin

  declare dom varchar(50);
  declare srv, cls varchar(50);
  declare sec varchar(100);
  declare tst varchar(600);
  declare det, un varchar(100);
  declare mt, gmt, ui, vid integer unsigned;
  declare dtype, ctype, wtype enum('num','str','dat','blob');
  declare fdwid, akid, slvgrpid integer unsigned;
  declare z integer;
  declare q, fkt varchar(10000);
  declare cnstvars, uwids varchar(3000);
  declare klimcur cursor for
    select a.ID, a.expression
    from autokombilimits as a
    left join kombilimits as k
      on k.serverID = si and k.sectionID = ei and k.teststepID = ti
        and k.accessID = aid and k.autokombilimitsID = a.ID
    where a.verfahrenID = vid and a.aktiv = '1' and k.ID is NULL and a.accessID = aid
      and testreg(cls, classes, classes_v)
      and testreg(srv, server, server_v) and testreg(sec, section, section_v)
      and testreg(tst, teststep, teststep_v) and find_in_set(det, details);
  declare gclimcur cursor for
    select ga.ID, ga.expression, gr.slavegroupID
    from gautocombilimits as ga
    join loggingtmp.grights as gr using(groupID)
    left join kombilimits as k
      on k.serverID = si and k.sectionID = ei and k.teststepID = ti
        and k.accessID = aid and k.groupautoID = ga.ID
    where ga.aktiv = '1' and ga.accessID = aid and k.ID is NULL
      and testreg(cls, classes, classes_v)
      and testreg(dom, domain, domain_v) and testreg(srv, server, server_v)
      and testreg(sec, section, section_v) and testreg(tst, teststep, teststep_v)
      and find_in_set(det, details);
  declare kdetcur cursor for
    select a.ID, a.formel, einheiten.type
    from autokombidetails as a
    join teststepdetails as td on td.ID = a.teststepdetailsID
    left join einheiten on einheiten.ID = einheitID and einheiten.type != 'str'
    left join kombidetails as k
      on k.serverID = si and k.sectionID = ei and k.teststepID = ti
        and k.accessID = aid and k.autokombidetailsID = a.ID
    where a.verfahrenID = vid and a.aktiv = '1' and k.ID is NULL and a.accessID = aid
      and testreg(srv, server, server_v) and testreg(sec, section, section_v)
      and testreg(tst, teststep, teststep_v) and find_in_set(det, details);
  declare gcdetcur cursor for
    select ga.ID, ga.formel, einheiten.type
    from gautocombidetails as ga
    join gruppenrechte as gr
      on gr.verfahrenID = vid and gr.accessID = aid and gr.gruppenID = ga.groupID
    join teststepdetails as td on td.ID = ga.teststepdetailsID
    left join einheiten on einheiten.ID = einheitID and einheiten.type != 'str'
    left join kombidetails as k
      on k.serverID = si and k.sectionID = ei and k.teststepID = ti
        and k.accessID = aid and k.groupautoID = ga.ID
    where ga.aktiv = '1' and ga.accessID = aid and k.ID is NULL
      and testreg(dom, domain, domain_v) and testreg(srv, server, server_v)
      and testreg(sec, section, section_v) and testreg(tst, teststep, teststep_v)
      and find_in_set(det, details);
  declare ccdetcur cursor for
    select a.ID, a.formel, einheiten.type
    from autoccdetails as a
    join teststepdetails as td on td.ID = a.teststepdetailsID
    left join einheiten on einheiten.ID = einheitID and einheiten.type != 'str'
    left join ccdetails as k
      on k.serverID = si and k.sectionID = ei and k.teststepID = ti
        and k.accessID = aid and k.domautoID = a.ID
    where a.verfahrenID = vid and a.aktiv = '1' and k.ID is NULL and a.accessID = aid
      and testreg(srv, server, server_v) and testreg(sec, section, section_v)
      and testreg(tst, teststep, teststep_v) and find_in_set(det, details);
  declare gccdetcur cursor for
    select ga.ID, ga.formel, einheiten.type
    from (gautoccdetails as ga, gruppenrechte as gr)
    join teststepdetails as td on td.ID = ga.teststepdetailsID
    left join einheiten on einheiten.ID = einheitID and einheiten.type != 'str'
    left join ccdetails as k
      on k.serverID = si and k.sectionID = ei and k.teststepID = ti
        and k.accessID = aid and k.groupautoID = ga.ID
    where gr.verfahrenID = vid and gr.accessID = aid and ga.groupID = gr.gruppenID
      and ga.aktiv = '1' and ga.accessID=aid and k.ID is NULL
      and testreg(dom, domain, domain_v) and testreg(srv, server, server_v)
      and testreg(sec, section, section_v) and testreg(tst, teststep, teststep_v)
      and find_in_set(det, details);
  declare continue handler for not found set z = 1;

  select servername, verfahrenID, verfahren.name, coalesce(serverclasses.name, '')
    from server
    join verfahren on verfahren.ID = server.verfahrenID
    left join serverclasses on serverclasses.ID = server.serverclassesID
      where server.ID = si
      into srv, vid, dom, cls;
  select name from section where ID=ei into sec;
  select name from teststep where ID=ti into tst;
  select name, einheitID from teststepdetails where ID = di into det, ui;
  select name, `type` from einheiten where ID = ui into un, wtype;

  insert into wertelimits
    (werteindizesID, autolimitsID, infowert, warnwert, errorwert, exclude, vergleich,
     groupfunctionsID, anzmittel, meldung, meldungszielID, ziel1level,
     meldungsziel2ID, ziel2level, notifymode, bemerkungen)
    select wi, autolimits.ID, infowert, warnwert, errorwert, exclude, vergleich,
      groupfunctionsID, if(code = 'diffto' and anzmittel = 'LAST', @dt, anzmittel), meldung,
      meldungszielID, ziel1level, meldungsziel2ID, ziel2level,
      notifymode, bemerkungen
    from autolimits, groupfunctions
    where verfahrenID = vid and testreg(srv, server, server_v)
      and testreg(cls, classes, classes_v)
      and testreg(sec, section, section_v) and testreg(tst, teststep, teststep_v)
      and testreg(det, details, details_v) and testreg(un, einheit, einheit_v)
      and groupfunctions.ID = groupfunctionsID and accessID = aid
      and if(notifymode like 'S%', find_in_set('str',flags) AND wtype = 'str',
             find_in_set(wtype,flags));

  create temporary table loggingtmp.grights (unique key uk(groupID, slavegroupID))
      select g.gruppenID as groupID, NULL as slavegroupID
      from gruppenrechte as g
      where g.verfahrenID = vid and g.accessID = aid and g.admin = '1'
    union all
      select gm.mastergroupID as groupID, g.gruppenID as slavegroupID
      from gruppenrechte as g
      join masterslavegroups as gm on gm.slavegroupID = g.gruppenID
      where g.verfahrenID = vid and g.accessID = aid and g.admin = '1';

  insert into wertelimits
    (werteindizesID, groupautoID, infowert, warnwert, errorwert, exclude, vergleich,
     groupfunctionsID, anzmittel, meldung, meldungszielID, ziel1level,
     meldungsziel2ID, ziel2level, notifymode, bemerkungen, slavegroupID)
    select wi, ga.ID, infowert, warnwert, errorwert, exclude, vergleich, groupfunctionsID,
      if(code = 'diffto' and anzmittel = 'LAST', @dt, anzmittel), meldung,
      meldungszielID, ziel1level, meldungsziel2ID, ziel2level,
      notifymode, bemerkungen, gr.slavegroupID
    from gautolimits as ga
    join loggingtmp.grights as gr using(groupID)
    join groupfunctions on groupfunctions.ID = groupfunctionsID
    where ga.accessID = aid and testreg(dom, domain, domain_v)
      and testreg(cls, classes, classes_v) and testreg(srv, server, server_v)
      and testreg(sec, section, section_v) and testreg(tst, teststep, teststep_v)
      and testreg(det, details, details_v) and testreg(un, einheit, einheit_v)
      and if(notifymode like 'S%', find_in_set('str', flags) AND wtype = 'str',
             find_in_set(wtype,flags));

  if 0 < (select count(*)
          from wertelimits as l
          left join gautolimits as ga on ga.ID = l.groupautoID and not ga.nootherflag
          where l.werteindizesID = wi and (ga.ID is not NULL OR l.autolimitsID > 0)) then
    update wertelimits as l
      join gautolimits as ga on ga.ID = l.groupautoID and ga.nootherflag
      set l.hidden = true
      where l.werteindizesID = wi;
  end if;


  insert into isalive
     (werteindizesID, maxperiods, intervalleID, meldung, meldungszielID, meldungsziel2ID,
      notifymode, autoisaliveID, bemerkungen, autoclose)
    select wi, maxperiods, intervalleID, meldung, meldungszielID, meldungsziel2ID,
      notifymode, ID, bemerkungen, autoclose
    from autoisalive
    where verfahrenID = vid and accessID = aid
      and testreg(cls, classes, classes_v)
      and testreg(srv, server, server_v) and testreg(sec, section, section_v)
      and testreg(tst, teststep, teststep_v) and testreg(det, details, details_v)
      and testreg(un, einheit, einheit_v);

  insert into isalive
     (werteindizesID, maxperiods, intervalleID, meldung, meldungszielID, meldungsziel2ID,
      notifymode, groupautoID, bemerkungen, autoclose, slavegroupID)
    select wi, maxperiods, intervalleID, meldung, meldungszielID, meldungsziel2ID,
      notifymode, ID, bemerkungen, autoclose, gr.slavegroupID
    from gautoisalive as ga
    join loggingtmp.grights as gr using(groupID)
    where ga.accessID = aid and testreg(dom, domain, domain_v)
      and testreg(cls, classes, classes_v) and testreg(srv, server, server_v)
      and testreg(sec, section, section_v) and testreg(tst, teststep, teststep_v)
      and testreg(det, details, details_v) and testreg(un, einheit, einheit_v);

  if 0 < (select count(*)
          from isalive as i
          left join gautoisalive as ga on ga.ID = i.groupautoID and not ga.nootherflag
          where i.werteindizesID = wi and (ga.ID is not NULL OR i.autoisaliveID > 0)) then
    update isalive as i
      join gautoisalive as ga on ga.ID = i.groupautoID and ga.nootherflag
      set i.hidden = true
      where i.werteindizesID = wi;
  end if;


  set z = 0;
  open klimcur;
  fetch klimcur into akid, fkt;
  while z != 1 do
    call convert_combi(si, ei, ti, aid, fkt, '', '', q, fdwid, ctype, cnstvars, uwids);
    if q != '' then
      insert into kombilimits 
        (serverID, sectionID, teststepID, expression, expressionsql, relation, infolevel,
         warnlevel, errorlevel, notifymode, meldung, meldungszielID, dest1level,
         meldungsziel2ID, dest2level, aktiv, autokombilimitsID, bemerkungen, accessID, usedwIDs)
        select si, ei, ti, expression, concat('select ', q), relation, infolevel, warnlevel,
          errorlevel, notifymode, meldung, meldungszielID, dest1level, meldungsziel2ID,
          dest2level, aktiv, ID, bemerkungen, accessID, trim(leading ',' from uwids)
        from autokombilimits
        where ID = akid;
    end if;
    fetch klimcur into akid, fkt;
  end while;
  close klimcur;

  set z = 0;
  open gclimcur;
  fetch gclimcur into akid, fkt, slvgrpid;
  while z != 1 do
    call convert_combi(si, ei, ti, aid, fkt, '', '', q, fdwid, ctype, cnstvars, uwids);
    if q != '' then
      insert into kombilimits
        (serverID, sectionID, teststepID, expression, expressionsql, relation, infolevel, warnlevel,
         errorlevel, notifymode, meldung, meldungszielID, dest1level, meldungsziel2ID,
         dest2level, aktiv, groupautoID, bemerkungen, accessID, usedwIDs, slavegroupID)
        select si, ei, ti, expression, concat('select ', q), relation, infolevel, warnlevel,
          errorlevel, notifymode, meldung, meldungszielID, dest1level, meldungsziel2ID,
          dest2level, aktiv, ID, bemerkungen, accessID, trim(leading ',' from uwids), slvgrpid
        from gautocombilimits
        where ID = akid;
    end if;
    fetch gclimcur into akid, fkt, slvgrpid;
  end while;
  close gclimcur;

  if 0 < (select count(*)
          from kombilimits as kl
          left join gautocombilimits as ga on ga.ID = kl.groupautoID and not ga.nootherflag
          where kl.serverID = si and kl.sectionID = ei and kl.teststepID = ti
            and (ga.ID is not NULL OR kl.autokombilimitsID > 0)) then
    update kombilimits as kl
      join gautocombilimits as ga on ga.ID = kl.groupautoID and ga.nootherflag
      set kl.hidden = true
      where kl.serverID = si and kl.sectionID = ei and kl.teststepID = ti;
  end if;

  set z = 0;
  open kdetcur;
  fetch kdetcur into akid, fkt, dtype;
  while z != 1 do
    call convert_combi(si, ei, ti, aid, fkt, 'b', 'datum,', q, fdwid, ctype, cnstvars, uwids);
    if q != '' then
      insert into kombidetails
        (serverID, sectionID, teststepID, teststepdetailsID, formel, formelsql,
         constvars, firstdetwiID, autokombidetailsID, bemerkungen, stringflag,
         aktiv, accessID, usedwIDs)
      select si, ei, ti, teststepdetailsID, formel, q,
        cnstvars, fdwid, ID, bemerkungen, coalesce(dtype, ctype) != 'num', '1', accessID, trim(leading ',' from uwids)
      from autokombidetails
      where ID = akid;
    end if;
    fetch kdetcur into akid, fkt, dtype;
  end while;
  close kdetcur;

  set z = 0;
  open gcdetcur;
  fetch gcdetcur into akid, fkt, dtype;
  while z != 1 do
    call convert_combi(si, ei, ti, aid, fkt, 'b', 'datum,', q, fdwid, ctype, cnstvars, uwids);
    if q != '' then
      insert into kombidetails
        (serverID, sectionID, teststepID, teststepdetailsID, formel, formelsql,
         constvars, firstdetwiID, groupautoID, bemerkungen, stringflag,
         aktiv, accessID, usedwIDs)
      select si, ei, ti, teststepdetailsID, formel, q,
        cnstvars, fdwid, ID, bemerkungen, coalesce(dtype, ctype) != 'num', '1', accessID, trim(leading ',' from uwids)
      from gautocombidetails
      where ID = akid;
    end if;
    fetch gcdetcur into akid, fkt, dtype;
  end while;
  close gcdetcur;

  set z = 0;
  open ccdetcur;
  fetch ccdetcur into akid, fkt, dtype;
  while z != 1 do
    call convert_ccombi(si, ei, ti, aid, fkt, 'b', 'datum,', q, fdwid, ctype, cnstvars, uwids);
    if q != '' then
      insert into ccdetails
        (serverID, sectionID, teststepID, teststepdetailsID, formel, formelsql,
         constvars, firstdetwiID, domautoID, bemerkungen, stringflag,
         aktiv, accessID, usedwIDs)
      select si, ei, ti, teststepdetailsID, formel, q,
        cnstvars, fdwid, ID, bemerkungen, coalesce(dtype, ctype) != 'num', '1', accessID, trim(leading ',' from uwids)
      from autoccdetails
      where ID = akid;
    end if;
    fetch ccdetcur into akid, fkt, dtype;
  end while;
  close ccdetcur;

  set z = 0;
  open gccdetcur;
  fetch gccdetcur into akid, fkt, dtype;
  while z != 1 do
    call convert_ccombi(si, ei, ti, aid, fkt, 'b', 'datum,', q, fdwid, ctype, cnstvars, uwids);
    if q != '' then
      insert into ccdetails
        (serverID, sectionID, teststepID, teststepdetailsID, formel, formelsql,
         constvars, firstdetwiID, groupautoID, bemerkungen, stringflag,
         aktiv, accessID, usedwIDs)
      select si, ei, ti, teststepdetailsID, formel, q,
        cnstvars, fdwid, ID, bemerkungen, coalesce(dtype, ctype) != 'num', '1', accessID, trim(leading ',' from uwids)
      from gautoccdetails
      where ID = akid;
    end if;
    fetch gccdetcur into akid, fkt, dtype;
  end while;
  close gccdetcur;

  if (select count(*) from autokomprimierung
      where verfahrenID = vid and accessID = aid
        and testreg(srv, server, server_v) and testreg(sec, section, section_v)
        and testreg(tst, teststep, teststep_v) and testreg(det, details, details_v)
        and testreg(un, einheit, einheit_v)) > 0 then
    call newkompautos(wi, cls, srv, sec, tst, det, un, vid, aid, wtype);
  end if;

  if (select count(*)
      from gautocompression as ga
      join loggingtmp.grights as gr using(groupID)
      where ga.accessID = aid and testreg(dom, domain, domain_v)
        and testreg(srv, server, server_v) and testreg(sec, section, section_v)
        and testreg(tst, teststep, teststep_v) and testreg(det, details, details_v)
        and testreg(un, einheit, einheit_v)) > 0 then
    call newgcompautos(wi, cls, srv, sec, tst, det, un, vid, aid, wtype);
  end if;

  drop temporary table loggingtmp.grights;

end//

GRANT EXECUTE on PROCEDURE newautos to logging@'localhost'//
