set @@character_set_client = 'utf8';

-- ----------------------------------------------
-- removemastergroups.sql
--
-- Wird aufgerufen aus Admin-Menue, wenn von einer
-- Gruppe Mastergruppen entfernt werden
--
-- ----------------------------------------------

delimiter //


DROP procedure IF EXISTS removemastergroups//
create procedure removemastergroups(groupid integer unsigned, maids varchar(10000))
  deterministic
  sql security invoker
 begin

  create temporary table loggingtmp.wids (
    ID integer unsigned not null default '0',
    primary key(ID));
--
--
-- Limits

  insert into loggingtmp.wids
    select distinct werteindizesID
    from wertelimits
    join gautolimits as ga on ga.ID = wertelimits.groupautoID and find_in_set(ga.groupID, maids)
    where wertelimits.slavegroupID = groupid;

  delete wertelimits from wertelimits
    join gautolimits as ga on ga.ID = wertelimits.groupautoID and find_in_set(ga.groupID, maids)
    where wertelimits.slavegroupID = groupid;

  create temporary table loggingtmp.ano (primary key(ID))
    select wids.ID, min(ga.nootherflag) as mnoflg
    from loggingtmp.wids
    join wertelimits as l on l.werteindizesID = wids.ID
    join gautolimits as ga on ga.ID = l.groupautoID
    group by wids.ID;
  update wertelimits as l
    join gautolimits as ga on ga.ID = l.groupautoID and ga.nootherflag
    join loggingtmp.ano on ano.ID = l.werteindizesID
    set l.hidden = not mnoflg;
  drop temporary table loggingtmp.ano;
--
--
-- isAlive

  delete from loggingtmp.wids;
  insert into loggingtmp.wids
    select distinct werteindizesID
    from isalive
    join gautoisalive as ga on ga.ID = isalive.groupautoID and find_in_set(ga.groupID, maids)
    where isalive.slavegroupID = groupid;

  delete isalive from isalive
    join gautoisalive as ga on ga.ID = isalive.groupautoID and find_in_set(ga.groupID, maids)
    where isalive.slavegroupID = groupid;

  create temporary table loggingtmp.ano (primary key(ID))
    select wids.ID, min(ga.nootherflag) as mnoflg
    from loggingtmp.wids
    join isalive as i on i.werteindizesID = wids.ID
    join gautoisalive as ga on ga.ID = i.groupautoID
    group by wids.ID;
  update isalive as i
    join gautoisalive as ga on ga.ID = i.groupautoID and ga.nootherflag
    join loggingtmp.ano on ano.ID = i.werteindizesID
    set i.hidden = not mnoflg;
  drop temporary table loggingtmp.ano;
--
--
-- kompr. Limits

  delete from loggingtmp.wids;
  insert into loggingtmp.wids
    select distinct lwerteindizesID
    from lwertelimits
    join gautoclimits as ga on ga.ID = lwertelimits.groupautoID and find_in_set(ga.groupID, maids)
    where lwertelimits.slavegroupID = groupid;

  delete lwertelimits from lwertelimits
    join gautoclimits as ga on ga.ID = lwertelimits.groupautoID and find_in_set(ga.groupID, maids)
    where lwertelimits.slavegroupID = groupid;

  create temporary table loggingtmp.ano (primary key(ID))
    select wids.ID, min(ga.nootherflag) as mnoflg
    from loggingtmp.wids
    join lwertelimits as l on l.lwerteindizesID = wids.ID
    join gautoclimits as ga on ga.ID = l.groupautoID
    group by wids.ID;
  update lwertelimits as l
    join loggingtmp.ano on ano.ID = l.lwerteindizesID
    join gautoclimits as ga on ga.ID = l.groupautoID and ga.nootherflag
    set l.hidden = not mnoflg;
  drop temporary table loggingtmp.ano, loggingtmp.wids;
--
--
-- Kombilimits

  create temporary table loggingtmp.sstids (
    serverID integer unsigned not null default '0',
    sectionID integer unsigned not null default '0',
    teststepID integer unsigned not null default '0',
    accessID integer unsigned not null default '0',
    primary key(serverID, sectionID, teststepID, accessID));
  insert into loggingtmp.sstids
    select serverID, sectionID, teststepID, kombilimits.accessID
    from kombilimits
    join gautocombilimits as ga on ga.ID = kombilimits.groupautoID and find_in_set(ga.groupID, maids)
    where kombilimits.slavegroupID = groupid;

  delete kombilimits from kombilimits
    join gautocombilimits as ga on ga.ID = kombilimits.groupautoID and find_in_set(ga.groupID, maids)
    where kombilimits.slavegroupID = groupid;

  create temporary table loggingtmp.ano (primary key(serverID, sectionID, teststepID, accessID))
    select sstids.serverID, sstids.sectionID, sstids.teststepID, sstids.accessID,
      min(ga.nootherflag) as mnoflg
    from loggingtmp.sstids
    join kombilimits as k
      on k.serverID = sstids.serverID and k.sectionID = sstids.sectionID
        and k.teststepID = sstids.teststepID and k.accessID = sstids.accessID
    join gautocombilimits as ga on ga.ID = k.groupautoID
    group by sstids.serverID, sstids.sectionID, sstids.teststepID, sstids.accessID;
  update kombilimits as k
    join gautocombilimits as ga on ga.ID = k.groupautoID and ga.nootherflag
    join loggingtmp.ano
      on k.serverID = ano.serverID and k.sectionID = ano.sectionID
        and k.teststepID = ano.teststepID and k.accessID = ano.accessID
    set k.hidden = not mnoflg;
  drop temporary table loggingtmp.ano, loggingtmp.sstids;

--
--
-- Compression
  delete komprimierungids from komprimierungids
    join gautocompression as ga on ga.ID = komprimierungids.groupautoID and find_in_set(ga.groupID, maids)
    where komprimierungids.slavegroupID = groupid;


end//
