set @@character_set_client = 'utf8';

#######################################
# rogroupautos.sql
#
# Wird aufgerufen aus Admin-Menue, wenn
# einer Gruppe Verfahren hinzugefuegt
# werden oder einem Verfahren Gruppen
# hinzugefuegt werden
#
#######################################

delimiter //

DROP procedure IF EXISTS gcsstids//
create procedure gcsstids(domids varchar(20000), aid integer unsigned,
                   dom varchar(500), domv varchar(300), s varchar(500), sv varchar(300),
                   e varchar(500), ev varchar(300), t varchar(500), tv varchar(300),
                   d varchar(500))
  deterministic
  sql security invoker
 begin

  create temporary table loggingtmp.srvids (primary key(ID))
    select distinct ID
    from server as s
    where find_in_set(s.verfahrenID, domids)
      and testreg(s.servername, s, sv);

  create temporary table loggingtmp.secids (primary key(ID))
    select ID from section
    where testreg(section.name, e, ev);

  create temporary table loggingtmp.tstids (primary key(ID))
    select ID from teststep
    where testreg(teststep.name, t, tv);

  create temporary table loggingtmp.gcsstids (primary key(serverID,sectionID,teststepID))
    select distinct lw.serverID, lw.sectionID, lw.teststepID
    from lwerteindizes as lw
    join loggingtmp.srvids on srvids.ID = lw.serverID
    join loggingtmp.secids on secids.ID = lw.sectionID
    join loggingtmp.tstids on tstids.ID = lw.teststepID
    join teststepdetails as d on d.ID = lw.teststepdetailsID
    join groupfunctions as gf on gf.ID = lw.groupfunctionsID
    where find_in_set(concat(gf.code, '[', left(period, 1), '](', d.name, ')'), d);

  drop temporary table if exists loggingtmp.srvids, loggingtmp.secids,
    loggingtmp.tstids;

end//

GRANT EXECUTE on PROCEDURE gcsstids to loggingadmin@'localhost'//



DROP procedure IF EXISTS rogroupautos//
create procedure rogroupautos(groupids varchar(20000), domids varchar(20000),
                              aid integer unsigned)
  deterministic
  sql security invoker
 begin
  declare dom, s, e, t, d varchar(500);
  declare domv, sv, ev, tv varchar(300);
  declare q, fkt varchar(10000);
  declare cnstvars, uwids varchar(3000);
  declare i, si, ci, ti, gaid, fdwid, z integer unsigned;
  declare dtype, ctype enum('num','str','dat','blob');
  declare gsstcur cursor for
    select serverID, sectionID, teststepID
    from loggingtmp.gsstids;
  declare gcsstcur cursor for
    select serverID, sectionID, teststepID
    from loggingtmp.gcsstids;
  declare gcdetcur cursor for
    select gautocombidetails.ID, domain, domain_v, server, server_v, section, section_v,
      teststep, teststep_v, details, formel, einheiten.type
    from gautocombidetails
    join teststepdetails as td on td.ID = teststepdetailsID
    left join einheiten on einheiten.ID = td.einheitID and einheiten.type != 'str'
    where aktiv = '1' and find_in_set(groupID, groupids);
  declare gccdetcur cursor for
    select gautoccdetails.ID, domain, domain_v, server, server_v, section, section_v,
      teststep, teststep_v, details, formel, einheiten.type
    from gautoccdetails
    join teststepdetails as td on td.ID = teststepdetailsID
    left join einheiten on einheiten.ID = td.einheitID and einheiten.type != 'str'
    where aktiv = '1' and find_in_set(groupID, groupids);
  declare continue handler for not found set z = 1;


-- Kombidetails

  open gcdetcur;
  set z = 0;
  fetch gcdetcur into gaid, dom, domv, s, sv, e, ev, t, tv, d, fkt, dtype;
  while z != 1 do
    call gsstids(domids, aid, dom, domv, '.*', '', s, sv, e, ev, t, tv, d);
    delete loggingtmp.gsstids from loggingtmp.gsstids
      join kombidetails as kd
        on kd.groupautoID = gaid and kd.serverID = gsstids.serverID
          and kd.sectionID = gsstids.sectionID and kd.teststepID = gsstids.teststepID;
    open gsstcur;
    set z = 0;
    fetch gsstcur into si, ci, ti;
    while z != 1 do
      call convert_combi(si, ci, ti, aid, fkt, 'b', 'datum,', q, fdwid, ctype, cnstvars, uwids);
      if q != '' then
        insert into kombidetails
          (serverID, sectionID, teststepID, teststepdetailsID, formel, formelsql,
           constvars, firstdetwiID, groupautoID, bemerkungen, stringflag,
           aktiv, accessID, usedwIDs)
        select si, ci, ti, teststepdetailsID, formel, q,
          cnstvars, fdwid, ID, bemerkungen, coalesce(dtype, ctype) != 'num', '1', accessID, trim(leading ',' from uwids)
        from gautocombidetails
        where ID = gaid;
      end if;
      fetch gsstcur into si, ci, ti;
    end while;
    close gsstcur;
    drop temporary table loggingtmp.gsstids;
    set z = 0;
    fetch gcdetcur into gaid, dom, domv, s, sv, e, ev, t, tv, d, fkt, dtype;
  end while;
  close gcdetcur;


-- komprimierte Kombidetails

  open gccdetcur;
  set z = 0;
  fetch gccdetcur into gaid, dom, domv, s, sv, e, ev, t, tv, d, fkt, dtype;
  while z != 1 do
    call gcsstids(domids, aid, dom, domv, s, sv, e, ev, t, tv, d);
    delete loggingtmp.gcsstids from loggingtmp.gcsstids
      join ccdetails as ccd
        on ccd.groupautoID = gaid and ccd.serverID = gcsstids.serverID
          and ccd.sectionID = gcsstids.sectionID and ccd.teststepID = gcsstids.teststepID;
    open gcsstcur;
    set z = 0;
    fetch gcsstcur into si, ci, ti;
    while z != 1 do
      call convert_ccombi(si, ci, ti, aid, fkt, 'b', 'datum,', q, fdwid, ctype, cnstvars, uwids);
      if q != '' then
        insert into ccdetails
          (serverID, sectionID, teststepID, teststepdetailsID, formel, formelsql,
           constvars, firstdetwiID, groupautoID, bemerkungen, stringflag,
           aktiv, accessID, usedwIDs)
        select si, ci, ti, teststepdetailsID, formel, q, cnstvars, fdwid, ID, bemerkungen,
          coalesce(dtype, ctype) != 'num', '1', accessID, trim(leading ',' from uwids)
        from gautoccdetails
        where ID = gaid;
      end if;
      fetch gcsstcur into si, ci, ti;
    end while;
    close gcsstcur;
    drop temporary table loggingtmp.gcsstids;
    set z = 0;
    fetch gccdetcur into gaid, dom, domv, s, sv, e, ev, t, tv, d, fkt, dtype;
  end while;
  close gccdetcur;

end//

GRANT EXECUTE on PROCEDURE rogroupautos to loggingadmin@'localhost'//
