#!/bin/bash
#
# postinst.sh
#
# Postinstall script
#
#######################################################################################
#
export PATH=/usr/local/bin:/usr/bin:$PATH
#
ULSDIR="$1"
#
MYSQLDEFAULTS="$2"
MYSQLO="mysql --defaults-extra-file=$MYSQLDEFAULTS -B -N logging"
#
#
# 1.9.4 -> 1.9.5
if [[ -f /etc/cron.d/ulsserver ]]
 then
  if ! grep -q 'do_ulsmeld.*test_grouped' /etc/cron.d/ulsserver
   then
    echo "#
# Grouped Monitoring
4/10 * * * * uls $ULSDIR/ulsmeld/do_ulsmeld test_grouped &>/dev/null" >>/etc/cron.d/ulsserver
  fi
else
  echo "Damit bei der gruppierten Überwachung die E-Mailbenachrichtiung läuft, muss
in die entsprechende crontab-Datei folgender Eintag ergänzt werden:
#
# Grouped Monitoring
4/10 * * * * uls $ULSDIR/ulsmeld/do_ulsmeld test_grouped &>/dev/null"
fi
#
# Unterstuetzung fuer performance_schema
#
PERF=`$MYSQLO -e "select VARIABLE_VALUE from performance_schema.global_status where VARIABLE_NAME = 'Threads_connected'" 2>/dev/null`
if [[ -n "$PERF" && $PERF -gt 0 ]]
 then
  for f in $ULSDIR/html*/logging/get_status.s2w
   do
    if fgrep -q 'from information_schema.GLOBAL_STATUS where' $f
     then
      sed -i 's/from information_schema.GLOBAL_STATUS where/from performance_schema.global_status where/' $f
    fi
  done
else
  for f in $ULSDIR/html*/logging/get_status.s2w
   do
    if fgrep -q 'from performance_schema.global_status where' $f
     then
      sed -i 's/from performance_schema.global_status where/from information_schema.GLOBAL_STATUS where/' $f
    fi
  done
fi
#
# Gnuplot mit pngcairo
#
if echo "set terminal" | gnuplot 2>&1 | fgrep -q pngcairo
 then
  if fgrep -q 'set terminal png font ' "$ULSDIR/html/user/loggingout_grafik.s3w"
   then
    echo "pngcairo is supportet by gnuplot - patch loggingout_grafik.s3w to pngcairo"
    sed -i 's/set terminal png font /set terminal pngcairo font /' "$ULSDIR/html/user/loggingout_grafik.s3w"
    sed -i 's/^#.*#set encoding utf8/set encoding utf8/;s/^set encoding iso_8859/#pngcairo is available#set encoding iso_8859/' "$ULSDIR/wwwbin/loggingout_grafik_prescript.plt"
    sed -i 's/ | recode UTF-8..ISO-8859-15 | gnuplot / | gnuplot /' "$ULSDIR/wwwbin/loggingout_grafik.sh"
  fi
else
  if fgrep -q 'set terminal pngcairo font ' "$ULSDIR/html/user/loggingout_grafik.s3w"
   then
    echo "pngcairo is not supportet by gnuplot - patch loggingout_grafik.s3w to png"
    sed -i 's/set terminal pngcairo font /set terminal png font /' "$ULSDIR/html/user/loggingout_grafik.s3w"
    sed -i 's/^set encoding utf8/#has no pngcairo#set encoding utf8/;s/^#.*#set encoding iso_8859/set encoding iso_8859/' "$ULSDIR/wwwbin/loggingout_grafik_prescript.plt"
    sed -i 's/ | gnuplot / | recode UTF-8..ISO-8859-15 | gnuplot /' "$ULSDIR/wwwbin/loggingout_grafik.sh"
  fi
fi
#
# Gnuplot mit linecolor
#
if gnuplot -V | grep -q 'gnuplot 4.[0-5]'
 then
  if grep -q '^set grid xtics ytics lt 1 linecolor rgb "#E0E0E0"' "$ULSDIR/wwwbin/loggingout_grafik_prescript.plt"
   then
    echo "gnuplot version is less than 4.6 change linetype for xytics"
    sed -i 's/^set grid xtics ytics lt 1 linecolor rgb "#E0E0E0"/#no support for linecolor#set grid xtics ytics lt 1 linecolor rgb "#E0E0E0"/' "$ULSDIR/wwwbin/loggingout_grafik_prescript.plt"
  fi
else
  if grep -q '^#.*#set grid xtics ytics lt 1 linecolor rgb "#E0E0E0"' "$ULSDIR/wwwbin/loggingout_grafik_prescript.plt"
   then
    echo "gnuplot version is greater or equal to 4.6 change linetype for xytics"
    sed -i 's/^#.*#set grid xtics ytics lt 1 linecolor rgb "#E0E0E0"/set grid xtics ytics lt 1 linecolor rgb "#E0E0E0"/' "$ULSDIR/wwwbin/loggingout_grafik_prescript.plt"
  fi
fi
#
# MariaDB regex
#
if cd $ULSDIR/ulsmeld
 then
  REGEXPFLAGS=`$MYSQLO -e "show variables like '%regex%'"`
  if [[ -z "$REGEXPFLAGS" ]]
   then
    grep -q "^ *%mysqlwrite[(]\"set default_regex_flags='DOTALL'\"[)]" test_limits.s2w && sed -i "s/^\( *%mysqlwrite[(]\"set default_regex_flags='DOTALL'\"[)]\)/%%\1/" ../html/user/login.i2w test_isalive.s2w test_klimits.s2w test_kombilimits.s2w test_limits.s2w utt_escalation.s2w
  else
    grep -q "^%% *%mysqlwrite[(]\"set default_regex_flags='DOTALL'\"[)]" test_limits.s2w && sed -i "s/^%%\( *%mysqlwrite[(]\"set default_regex_flags='DOTALL'\"[)]\)/\1/" ../html/user/login.i2w test_isalive.s2w test_klimits.s2w test_kombilimits.s2w test_limits.s2w utt_escalation.s2w
  fi
fi
