set @@character_set_client = 'utf8';

-- ----------------------------------------------
-- addmastergroups.sql
--
-- Wird aufgerufen, wenn Mastergruppen zugeordnet werden
--
-- ----------------------------------------------

delimiter //


DROP procedure IF EXISTS addmastergroups//
create procedure addmastergroups(grpid integer unsigned, maids varchar(10000))
  deterministic
  sql security invoker
 begin
  declare dom, s, e, t, d varchar(500);
  declare domv, sv, ev, tv, dv varchar(300);
  declare cls, u varchar(200);
  declare clsv, uv varchar(100);
  declare q, fkt, domids varchar(10000);
  declare cnstvars, uwids varchar(3000);
  declare si, ci, ti, gaid, aid, slaveid, fdwid, z integer unsigned;
  declare ctype enum('num','str','dat','blob');
  declare hids, dids, wids, mids varchar(100);
  declare spids varchar(30);
  declare glimcur cursor for
    select ID, mg.slavegroupID, domain, domain_v, classes, classes_v, server, server_v, section, section_v,
      teststep, teststep_v, details, details_v, einheit, einheit_v, accessID
    from gautolimits as gal
    join masterslavegroups as mg
      on mg.mastergroupID = gal.groupID and mg.slavegroupID = grpid and find_in_set(mg.mastergroupID, maids);
  declare gisacur cursor for
    select ID, mg.slavegroupID, domain, domain_v, classes, classes_v, server, server_v, section, section_v,
      teststep, teststep_v, details, details_v, einheit, einheit_v, accessID
    from gautoisalive as gai
    join masterslavegroups as mg
      on mg.mastergroupID = gai.groupID and mg.slavegroupID = grpid and find_in_set(mg.mastergroupID, maids);
  declare gcmblimcur cursor for
    select ID, mg.slavegroupID, domain, domain_v, classes, classes_v, server, server_v, section, section_v,
      teststep, teststep_v, details, expression, accessID
    from gautocombilimits as gac
    join masterslavegroups as mg
      on mg.mastergroupID = gac.groupID and mg.slavegroupID = grpid and find_in_set(mg.mastergroupID, maids);
  declare gsstcur cursor for
    select serverID, sectionID, teststepID
    from loggingtmp.gsstids;
  declare gcmplimcur cursor for
    select ID, mg.slavegroupID, domain, domain_v, classes, classes_v, server, server_v, section, section_v,
      teststep, teststep_v, details, details_v, einheit, einheit_v, accessID
    from gautoclimits as gacl
    join masterslavegroups as mg
      on mg.mastergroupID = gacl.groupID and mg.slavegroupID = grpid and find_in_set(mg.mastergroupID, maids);
  declare gcomprcur cursor for
    select ID, mg.slavegroupID, domain, domain_v, server, server_v, section, section_v,
      teststep, teststep_v, details, details_v, einheit, einheit_v,
      hourIDs, dayIDs, weekIDs, monthIDs, specialIDs, accessID
    from gautocompression
    left join masterslavegroups as mg on mg.mastergroupID = gautocompression.groupID
    where aktiv = '1' and mg.slavegroupID = grpid;
  declare continue handler for not found set z = 1;

  set domids = (select group_concat(verfahrenID separator ',') from gruppenrechte where gruppenID = grpid and admin = '1');

  create temporary table loggingtmp.wids (
    ID integer unsigned not null default '0',
    primary key(ID));

-- Limits

  set z = 0;
  open glimcur;
  fetch glimcur into gaid, slaveid, dom, domv, cls, clsv, s, sv, e, ev, t, tv, d, dv, u, uv, aid;
  while z != 1 do
    call gwids(domids, grpid, aid, dom, domv, cls, clsv, s, sv, e, ev, t, tv, d, dv, u, uv);
    delete loggingtmp.gwids from loggingtmp.gwids
      join wertelimits
        on wertelimits.groupautoID = gaid and wertelimits.slavegroupID <=> slaveid
          and wertelimits.werteindizesID = gwids.ID;
    insert into wertelimits
      (werteindizesID, slavegroupID, groupautoID, infowert, warnwert, errorwert, exclude, vergleich,
       groupfunctionsID, anzmittel, meldung, meldungszielID, ziel1level,
       meldungsziel2ID, ziel2level, notifymode, bemerkungen)
      select gwids.ID, slaveid, gaid, ga.infowert, ga.warnwert, ga.errorwert, ga.exclude, ga.vergleich,
        ga.groupfunctionsID, ga.anzmittel, ga.meldung, ga.meldungszielID, ga.ziel1level,
        ga.meldungsziel2ID, ga.ziel2level, ga.notifymode, ga.bemerkungen
      from gautolimits as ga
      join groupfunctions on groupfunctions.ID = ga.groupfunctionsID
      join loggingtmp.gwids
      where ga.ID = gaid
        and if(ga.notifymode like 'S%', find_in_set('str',flags) AND wtype = 'str',
               find_in_set(wtype,flags));
    insert ignore into loggingtmp.wids select ID from loggingtmp.gwids;
    drop temporary table loggingtmp.gwids;
    fetch glimcur into gaid, slaveid, dom, domv, cls, clsv, s, sv, e, ev, t, tv, d, dv, u, uv, aid;
  end while;
  close glimcur;

  create temporary table loggingtmp.ano (primary key(werteindizesID))
    select werteindizesID, min(ga.nootherflag) as mnoflg
    from loggingtmp.wids
    join wertelimits as l on l.werteindizesID = wids.ID
    join gautolimits as ga on ga.ID = l.groupautoID
    group by werteindizesID;
  create temporary table loggingtmp.om (primary key(werteindizesID, groupID))
    select werteindizesID, ga.groupID
    from wertelimits
    join loggingtmp.ano using (werteindizesID)
    join gautolimits as ga on ga.ID = wertelimits.groupautoID and ga.overridemaster
    group by werteindizesID, ga.groupID;
  update wertelimits as l
    join loggingtmp.ano using(werteindizesID)
    join gautolimits as ga on ga.ID = l.groupautoID
    left join loggingtmp.om
      on om.werteindizesID = l.werteindizesID and om.groupID = l.slavegroupID
    set l.hidden = if(ga.nootherflag, not ano.mnoflg, om.werteindizesID is not NULL)
    where ga.nootherflag OR l.slavegroupID is not NULL;
  drop temporary table loggingtmp.om, loggingtmp.ano;


-- isAlive

  delete from loggingtmp.wids;
  set z = 0;
  open gisacur;
  fetch gisacur into gaid, slaveid, dom, domv, cls, clsv, s, sv, e, ev, t, tv, d, dv, u, uv, aid;
  while z != 1 do
    call gwids(domids, grpid, aid, dom, domv, cls, clsv, s, sv, e, ev, t, tv, d, dv, u, uv);
    delete loggingtmp.gwids from loggingtmp.gwids
      join isalive
        on isalive.groupautoID = gaid and isalive.slavegroupID <=> slaveid
          and isalive.werteindizesID = gwids.ID;
    insert into isalive
      (werteindizesID, slavegroupID, groupautoID, maxperiods, intervalleID, meldung, meldungszielID,
       meldungsziel2ID, notifymode, bemerkungen, autoclose, msglevel)
      select gwids.ID, slaveid, gaid, ga.maxperiods, ga.intervalleID, ga.meldung, ga.meldungszielID,
        ga.meldungsziel2ID, ga.notifymode, ga.bemerkungen, ga.autoclose, ga.msglevel
      from gautoisalive as ga, loggingtmp.gwids
      where ga.ID = gaid;
    insert ignore into loggingtmp.wids select ID from loggingtmp.gwids;
    drop temporary table loggingtmp.gwids;
    fetch gisacur into gaid, slaveid, dom, domv, cls, clsv, s, sv, e, ev, t, tv, d, dv, u, uv, aid;
  end while;
  close gisacur;

  create temporary table loggingtmp.ano (primary key(werteindizesID))
    select werteindizesID, min(ga.nootherflag) as mnoflg
    from loggingtmp.wids
    join isalive as i on i.werteindizesID = wids.ID
    join gautoisalive as ga on ga.ID = i.groupautoID
    group by werteindizesID;
  create temporary table loggingtmp.om (primary key(werteindizesID, groupID))
    select werteindizesID, ga.groupID
    from isalive
    join loggingtmp.ano using (werteindizesID)
    join gautoisalive as ga on ga.ID = isalive.groupautoID and ga.overridemaster
    group by werteindizesID, ga.groupID;
  update isalive
    join loggingtmp.ano using(werteindizesID)
    join gautoisalive on gautoisalive.ID = isalive.groupautoID
    left join loggingtmp.om
      on om.werteindizesID = isalive.werteindizesID and om.groupID = isalive.slavegroupID
    set isalive.hidden = if(gautoisalive.nootherflag, not ano.mnoflg, om.werteindizesID is not NULL)
    where gautoisalive.nootherflag OR isalive.slavegroupID is not NULL;
  drop temporary table loggingtmp.om, loggingtmp.ano;


-- Kombilimits

  create temporary table loggingtmp.sstids (
    serverID integer unsigned not null default '0',
    sectionID integer unsigned not null default '0',
    teststepID integer unsigned not null default '0',
    accessID integer unsigned not null default '0',
    primary key(serverID, sectionID, teststepID, accessID));
  open gcmblimcur;
  set z = 0;
  fetch gcmblimcur into gaid, slaveid, dom, domv, cls, clsv, s, sv, e, ev, t, tv, d, fkt, aid;
  while z != 1 do
    call gsstids(domids, grpid, aid, dom, domv, cls, clsv, s, sv, e, ev, t, tv, d);
    delete loggingtmp.gsstids from loggingtmp.gsstids
      join kombilimits as kl
        on kl.groupautoID = gaid and kl.slavegroupID <=> slaveid and kl.serverID = gsstids.serverID
          and kl.sectionID = gsstids.sectionID and kl.teststepID = gsstids.teststepID;
    open gsstcur;
    set z = 0;
    fetch gsstcur into si, ci, ti;
    while z != 1 do
      call convert_combi(si, ci, ti, aid, fkt, '', '', q, fdwid, ctype, cnstvars, uwids);
      if q != '' then
        insert into kombilimits
          (serverID, sectionID, teststepID, expression, expressionsql, relation, infolevel,
           warnlevel, errorlevel, notifymode, meldung, meldungszielID, dest1level,
           meldungsziel2ID, dest2level, aktiv, slavegroupID, groupautoID, bemerkungen, accessID, usedwIDs)
          select si, ci, ti, expression, concat('select ', q), relation, infolevel,
            warnlevel, errorlevel, notifymode, meldung, meldungszielID, dest1level,
            meldungsziel2ID, dest2level, aktiv, slaveid, ID, bemerkungen, aid, trim(leading ',' from uwids)
          from gautocombilimits
          where ID = gaid;
      end if;
      fetch gsstcur into si, ci, ti;
    end while;
    close gsstcur;

    insert ignore into loggingtmp.sstids (serverID, sectionID, teststepID, accessID)
      select serverID, sectionID, teststepID, aid  from loggingtmp.gsstids;
    drop temporary table loggingtmp.gsstids;
    set z = 0;
    fetch gcmblimcur into gaid, slaveid, dom, domv, cls, clsv, s, sv, e, ev, t, tv, d, fkt, aid;
  end while;
  close gcmblimcur;

  create temporary table loggingtmp.ano (primary key(serverID, sectionID, teststepID, accessID))
    select sstids.serverID, sstids.sectionID, sstids.teststepID, sstids.accessID,
      min(ga.nootherflag) as mnoflg
    from loggingtmp.sstids
    join kombilimits as k
      on k.serverID = sstids.serverID and k.sectionID = sstids.sectionID
        and k.teststepID = sstids.teststepID and k.accessID = sstids.accessID
    join gautocombilimits as ga on ga.ID = k.groupautoID
    group by sstids.serverID, sstids.sectionID, sstids.teststepID, sstids.accessID;
  create temporary table loggingtmp.om (primary key(serverID, sectionID, teststepID, groupID, accessID))
    select serverID, sectionID, teststepID, ga.groupID, ano.accessID
    from kombilimits
    join loggingtmp.ano using (serverID, sectionID, teststepID, accessID)
    join gautocombilimits as ga on ga.ID = kombilimits.groupautoID and ga.overridemaster
    group by serverID, sectionID, teststepID, ga.groupID;
  update kombilimits
    join loggingtmp.ano using(serverID, sectionID, teststepID, accessID)
    join gautocombilimits as ga on ga.ID = kombilimits.groupautoID
    left join loggingtmp.om
      on om.serverID = kombilimits.serverID and om.sectionID = kombilimits.sectionID
        and om.teststepID = kombilimits.teststepID and om.groupID = kombilimits.slavegroupID
    set kombilimits.hidden = if(ga.nootherflag, NOT ano.mnoflg, om.serverID is not NULL)
    where ga.nootherflag OR kombilimits.slavegroupID is not NULL;
  drop temporary table loggingtmp.om, loggingtmp.ano, loggingtmp.sstids;

-- Group-Autokomprimierung

  create temporary table loggingtmp.tgcwids (
    lwID integer unsigned not null default '0',
    primary key (lwID));
  set z = 0;
  open gcomprcur;
  fetch gcomprcur into gaid, slaveid, dom, domv, s, sv, e, ev, t, tv, d, dv, u, uv,
    hids, dids, wids, mids, spids, aid;
  while z != 1 do
    call gwids(domids, grpid, aid, dom, domv, '.*', '', s, sv, e, ev, t, tv, d, dv, u, uv);
    if hids != '' then
      insert ignore into lwerteindizes
        (serverID, sectionID, teststepID, teststepdetailsID, accessID,
         groupfunctionsID, period)
        select serverID, sectionID, teststepID, teststepdetailsID, accessID,
          groupfunctions.ID, 'Hour'
        from loggingtmp.gwids
        join groupfunctions
          on find_in_set(groupfunctions.ID, hids) and find_in_set(gwids.wtype, aggregationtypes);
      insert ignore into komprimierungids (groupautoID, lwerteindizesID, slavegroupID)
        select gaid, lwerteindizes.ID, grpid
        from lwerteindizes
        join loggingtmp.gwids
          using(serverID, sectionID, teststepID, teststepdetailsID, accessID)
        where find_in_set(groupfunctionsID, hids) and period = 'Hour';
      insert ignore into loggingtmp.tgcwids (lwID)
        select lwerteindizes.ID
        from lwerteindizes
        join loggingtmp.gwids
          using(serverID, sectionID, teststepID, teststepdetailsID, accessID)
        where find_in_set(groupfunctionsID, hids) and period = 'Hour';
    end if;
    if dids != '' then
      insert ignore into lwerteindizes
        (serverID, sectionID, teststepID, teststepdetailsID, accessID,
         groupfunctionsID, period)
        select serverID, sectionID, teststepID, teststepdetailsID, accessID,
          groupfunctions.ID, 'Day'
        from loggingtmp.gwids
        join groupfunctions
          on find_in_set(groupfunctions.ID, dids) and find_in_set(gwids.wtype, aggregationtypes);
      insert ignore into komprimierungids (groupautoID, lwerteindizesID, slavegroupID)
        select gaid, lwerteindizes.ID, grpid
        from lwerteindizes
        join loggingtmp.gwids
          using(serverID, sectionID, teststepID, teststepdetailsID, accessID)
        where find_in_set(groupfunctionsID, dids) and period = 'Day';
      insert ignore into loggingtmp.tgcwids (lwID)
        select lwerteindizes.ID
        from lwerteindizes
        join loggingtmp.gwids
          using(serverID, sectionID, teststepID, teststepdetailsID, accessID)
        where find_in_set(groupfunctionsID, dids) and period = 'Day';
    end if;
    if wids != '' then
      insert ignore into lwerteindizes
        (serverID, sectionID, teststepID, teststepdetailsID, accessID,
         groupfunctionsID, period)
        select serverID, sectionID, teststepID, teststepdetailsID, accessID,
          groupfunctions.ID, 'Week'
        from loggingtmp.gwids
        join groupfunctions
          on find_in_set(groupfunctions.ID, wids) and find_in_set(gwids.wtype, aggregationtypes);
      insert ignore into komprimierungids (groupautoID, lwerteindizesID, slavegroupID)
        select gaid, lwerteindizes.ID, grpid
        from lwerteindizes
        join loggingtmp.gwids
          using(serverID, sectionID, teststepID, teststepdetailsID, accessID)
        where find_in_set(groupfunctionsID, wids) and period = 'Week';
      insert ignore into loggingtmp.tgcwids (lwID)
        select lwerteindizes.ID
        from lwerteindizes
        join loggingtmp.gwids
          using(serverID, sectionID, teststepID, teststepdetailsID, accessID)
        where find_in_set(groupfunctionsID, wids) and period = 'Week';
    end if;
    if mids != '' then
      insert ignore into lwerteindizes
        (serverID, sectionID, teststepID, teststepdetailsID, accessID,
         groupfunctionsID, period)
        select serverID, sectionID, teststepID, teststepdetailsID, accessID,
          groupfunctions.ID, 'Month'
        from loggingtmp.gwids
        join groupfunctions
          on find_in_set(groupfunctions.ID, mids) and find_in_set(gwids.wtype, aggregationtypes);
      insert ignore into komprimierungids (groupautoID, lwerteindizesID, slavegroupID)
        select gaid, lwerteindizes.ID, grpid
        from lwerteindizes
        join loggingtmp.gwids
          using(serverID, sectionID, teststepID, teststepdetailsID, accessID)
        where find_in_set(groupfunctionsID, mids) and period = 'Month';
      insert ignore into loggingtmp.tgcwids (lwID)
        select lwerteindizes.ID
        from lwerteindizes
        join loggingtmp.gwids
          using(serverID, sectionID, teststepID, teststepdetailsID, accessID)
        where find_in_set(groupfunctionsID, mids) and period = 'Month';
    end if;
    if spids != '' then
      insert ignore into lwerteindizes
        (serverID, sectionID, teststepID, teststepdetailsID, accessID,
         groupfunctionsID, period)
        select serverID, sectionID, teststepID, teststepdetailsID, accessID,
          groupfunctions.ID, 'special'
        from loggingtmp.gwids
        join groupfunctions
          on find_in_set(groupfunctions.ID, spids) and find_in_set(gwids.wtype, aggregationspecialtypes);
      insert ignore into komprimierungids (groupautoID, lwerteindizesID, slavegroupID)
        select gaid, lwerteindizes.ID, grpid
        from lwerteindizes
        join loggingtmp.gwids
          using(serverID, sectionID, teststepID, teststepdetailsID, accessID)
        where find_in_set(groupfunctionsID, spids) and period = 'special';
      insert ignore into loggingtmp.tgcwids (lwID)
        select lwerteindizes.ID
          from lwerteindizes
        join loggingtmp.gwids
          using(serverID, sectionID, teststepID, teststepdetailsID, accessID)
        where find_in_set(groupfunctionsID, spids) and period = 'special';
    end if;
    drop temporary table loggingtmp.gwids;
    fetch gcomprcur into gaid, slaveid, dom, domv, s, sv, e, ev, t, tv, d, dv, u, uv,
      hids, dids, wids, mids, spids, aid;
  end while;
  close gcomprcur;

  drop temporary table loggingtmp.tgcwids;


-- kompr. Limits

  delete from loggingtmp.wids;
  set z = 0;
  open gcmplimcur;
  fetch gcmplimcur into gaid, slaveid, dom, domv, cls, clsv, s, sv, e, ev, t, tv, d, dv, u, uv, aid;
  while z != 1 do
    call gcwids(domids, grpid, aid, dom, domv, cls, clsv, s, sv, e, ev, t, tv, d, dv, u, uv);
    delete loggingtmp.gcwids from loggingtmp.gcwids
      join lwertelimits
        on lwertelimits.groupautoID = gaid and lwertelimits.slavegroupID <=> slaveid
          and lwertelimits.lwerteindizesID = gcwids.ID;
    insert into lwertelimits
      (lwerteindizesID, slavegroupID, groupautoID, infowert, warnwert, errorwert, vergleich,
       groupfunctionsID, anzmittel, meldung, meldungszielID, ziel1level,
       meldungsziel2ID, ziel2level, bemerkungen)
      select gcwids.ID, slaveid, gaid, infowert, warnwert, errorwert, vergleich,
        groupfunctionsID, anzmittel, meldung, meldungszielID, ziel1level,
        meldungsziel2ID, ziel2level, bemerkungen
      from gautoclimits as ga, loggingtmp.gcwids
      where ga.ID = gaid;
    insert ignore into loggingtmp.wids select ID from loggingtmp.gcwids;
    drop temporary table loggingtmp.gcwids;
    fetch gcmplimcur into gaid, slaveid, dom, domv, cls, clsv, s, sv, e, ev, t, tv, d, dv, u, uv, aid;
  end while;
  close gcmplimcur;

  create temporary table loggingtmp.ano (primary key(lwerteindizesID))
    select l.lwerteindizesID, min(ga.nootherflag) as mnoflg
    from loggingtmp.wids
    join lwertelimits as l on l.lwerteindizesID = wids.ID
    join gautoclimits as ga on ga.ID = l.groupautoID
    group by wids.ID;
  create temporary table loggingtmp.om (primary key(lwerteindizesID, groupID))
    select lwerteindizesID, ga.groupID
    from lwertelimits
    join loggingtmp.ano using (lwerteindizesID)
    join gautoclimits as ga on ga.ID = lwertelimits.groupautoID and ga.overridemaster
    group by lwerteindizesID, ga.groupID;
  update lwertelimits
    join loggingtmp.ano using(lwerteindizesID)
    join gautoclimits as ga on ga.ID = lwertelimits.groupautoID
    left join loggingtmp.om
      on om.lwerteindizesID = lwertelimits.lwerteindizesID and om.groupID = lwertelimits.slavegroupID
    set lwertelimits.hidden = if(ga.nootherflag, NOT ano.mnoflg, om.lwerteindizesID is not NULL)
    where ga.nootherflag OR lwertelimits.slavegroupID is not NULL;
  drop temporary table loggingtmp.om, loggingtmp.ano, loggingtmp.wids;

end//
