set @@character_set_client = 'utf8';

delimiter //

drop trigger if exists autollimits_au//
create trigger autollimits_au after update on autollimits
  for each row 
begin
  insert into changeprot
    (domainID, accessID, changedtable, tableID,
     userID, username, action, classes, server, section, teststep, details, unit, newvalues)
  select NEW.verfahrenID, NEW.accessID, 'autollimits', NEW.ID,
    coalesce(@userid,0), coalesce(@username,'SYSTEM'), 'update',
    showreg(NEW.classes, NEW.classes_v), showreg(NEW.server, NEW.server_v), showreg(NEW.section, NEW.section_v),
    showreg(NEW.teststep, NEW.teststep_v), showreg(NEW.details, NEW.details_v),
    showreg(NEW.einheit, NEW.einheit_v),
    concat('function=', g.code, '\nover=', NEW.anzmittel, '\nrelation=', NEW.vergleich,
           '\ninfolevel=', NEW.infowert, '\nwarnlevel=', NEW.warnwert, '\nerrorlevel=', NEW.errorwert,
           '\nnotifymode=', NEW.notifymode, '\nmessage=', REPLACE(REPLACE(NEW.meldung, '\\', '\\\\'), '\n', '\\n'),
           '\ndestination1=', notifdestname(NEW.meldungszielID), '\ndest1levels=',
           if(find_in_set('INFO', NEW.ziel1level), 'I', ''),
           if(find_in_set('WARN', NEW.ziel1level), 'W', ''),
           if(find_in_set('ERROR', NEW.ziel1level), 'F', ''), '\ndestination2=',
           notifdestname(NEW.meldungsziel2ID), '\ndest2levels=',
           if(find_in_set('INFO', NEW.ziel2level), 'I', ''),
           if(find_in_set('WARN', NEW.ziel2level), 'W', ''),
           if(find_in_set('ERROR', NEW.ziel2level), 'F', ''), '\nremark=',
           REPLACE(REPLACE(NEW.bemerkungen, '\\', '\\\\'), '\n', '\\n'), '\nactive=', NEW.aktiv)
  from groupfunctions as g
  where NEW.TS != OLD.TS and g.ID = NEW.groupfunctionsID;
end//


drop trigger if exists autollimits_ai//
create trigger autollimits_ai after insert on autollimits
  for each row 
begin
  insert into changeprot
    (domainID, accessID, changedtable, tableID,
     userID, username, action, classes, server, section, teststep, details, unit, newvalues)
  select NEW.verfahrenID, NEW.accessID, 'autollimits', NEW.ID,
    coalesce(@userid,0), coalesce(@username,'SYSTEM'), 'insert',
    showreg(NEW.classes, NEW.classes_v), showreg(NEW.server, NEW.server_v), showreg(NEW.section, NEW.section_v),
    showreg(NEW.teststep, NEW.teststep_v), showreg(NEW.details, NEW.details_v),
    showreg(NEW.einheit, NEW.einheit_v),
    concat('function=', g.code, '\nover=', NEW.anzmittel, '\nrelation=', NEW.vergleich,
           '\ninfolevel=', NEW.infowert, '\nwarnlevel=', NEW.warnwert, '\nerrorlevel=', NEW.errorwert,
           '\nnotifymode=', NEW.notifymode, '\nmessage=', REPLACE(REPLACE(NEW.meldung, '\\', '\\\\'), '\n', '\\n'),
           '\ndestination1=', notifdestname(NEW.meldungszielID), '\ndest1levels=',
           if(find_in_set('INFO', NEW.ziel1level), 'I', ''),
           if(find_in_set('WARN', NEW.ziel1level), 'W', ''),
           if(find_in_set('ERROR', NEW.ziel1level), 'F', ''), '\ndestination2=',
           notifdestname(NEW.meldungsziel2ID), '\ndest2levels=',
           if(find_in_set('INFO', NEW.ziel2level), 'I', ''),
           if(find_in_set('WARN', NEW.ziel2level), 'W', ''),
           if(find_in_set('ERROR', NEW.ziel2level), 'F', ''), '\nremark=',
           REPLACE(REPLACE(NEW.bemerkungen, '\\', '\\\\'), '\n', '\\n'), '\nactive=', NEW.aktiv)
  from groupfunctions as g
  where g.ID = NEW.groupfunctionsID;
end//


drop trigger if exists autollimits_bd//
create trigger autollimits_bd before delete on autollimits
  for each row 
begin
  insert into changeprot
    (domainID, accessID, changedtable, tableID,
     userID, username, action, classes, server, section, teststep, details, unit, newvalues)
  values
    (OLD.verfahrenID, OLD.accessID, 'autollimits', OLD.ID,
     coalesce(@userid,0), coalesce(@username,'SYSTEM'), 'delete',
     showreg(OLD.classes, OLD.classes_v), showreg(OLD.server, OLD.server_v), showreg(OLD.section, OLD.section_v),
     showreg(OLD.teststep, OLD.teststep_v), showreg(OLD.details, OLD.details_v),
     showreg(OLD.einheit, OLD.einheit_v),
     coalesce(if(OLD.bemerkungen = @complimitsremark, '', concat('remark=', REPLACE(REPLACE(@complimitsremark, '\\', '\\\\'), '\n', '\\n'))),''));
end//

delimiter ;
