set @@character_set_client = 'utf8';

-- Ueberwachungspausen bereinigen
--
-- Es werden Ueberwachungspausen geloescht, fuer die gilt:
--   Endedatum vor 3 Tagen
--   kein zugehoeriges Verfahren
--   server nicht leer
--   startdate aelter als 2 Monate
--   enddate fruehestens in 1 Monat
--   keine moegliche Kombination aus Server Sektion Teststep Detail vorhanden
--

delimiter //

DROP procedure IF EXISTS cleansuspensions//
create procedure cleansuspensions()
  deterministic
  sql security invoker
  begin
    declare uid, vid, nid, aid, z integer unsigned;
    declare srv, sec, tst, det varchar(500);
    declare srvv, secv, tstv, detv varchar(300);
    declare cla, unit varchar(200);
    declare clav, unitv varchar(100);
    declare ucur cursor for
      select u.ID, un.ID, u.verfahrenID, u.accessID, u.server, u.server_v, u.classes, u.classes_v,
        u.section, u.section_v, u.teststep, u.teststep_v, u.details, u.details_v, u.einheit, u.einheit_v
      from ueberwachungspausen as u
      left join ueberwachungspausen as un on un.nextdayID = u.ID
      where u.server != '.*' and u.nextdayID = 0 and u.datumvon < curdate() - interval 2 month
        and u.datumbis > curdate() + interval 1 month
      order by u.verfahrenID;
    declare continue handler for not found set z = 1;

    -- vor 3 Tagen abgelaufen
    delete from ueberwachungspausen where datumbis < curdate() - interval 3 day;

    -- kein Verfahren mehr
    delete ueberwachungspausen from ueberwachungspausen
      left join verfahren on verfahrenID=verfahren.ID
      where verfahren.ID is NULL;

    -- keine Auswirkungen mehr
    set @suspensionremark = 'suspension without effect';
    open ucur;
    set z = 0;
    fetch ucur into uid, nid, vid, aid, srv, srvv, cla, clav, sec, secv, tst, tstv, det, detv, unit, unitv;
    while z != 1 do
      if unit = '.*' AND unitv = '' then
        if det = '.*' AND detv = '' then
          if tst = '.*' AND tstv = '' then
            if sec = '.*' AND secv = '' then
              if cla = '.*' AND clav = '' then
                if not exists (select * from werteindizes
                     join server on server.ID = serverID and server.verfahrenID = vid and testreg(server.servername, srv, srvv)
                     where accessID = aid) then
                  if not exists (select * from lwerteindizes
                       join server on server.ID = serverID and server.verfahrenID = vid and testreg(server.servername, srv, srvv)
                       where accessID = aid) then
                    delete from ueberwachungspausen where ID = uid;
                    if nid is not NULL then
                      delete from ueberwachungspausen where ID = nid;
                    end if;
                  end if;
                end if;
              else
                if not exists (select * from werteindizes
                     join server on server.ID = serverID and server.verfahrenID = vid and testreg(server.servername, srv, srvv)
                     left join serverclasses on serverclasses.ID = serverclassesID
                     where accessID = aid and testreg(coalesce(serverclasses.name, ''), cla, clav)) then
                  if not exists (select * from lwerteindizes
                       join server on server.ID = serverID and server.verfahrenID = vid and testreg(server.servername, srv, srvv)
                       left join serverclasses on serverclasses.ID = serverclassesID
                       where accessID = aid and testreg(coalesce(serverclasses.name, ''), cla, clav)) then
                    delete from ueberwachungspausen where ID = uid;
                    if nid is not NULL then
                      delete from ueberwachungspausen where ID = nid;
                    end if;
                  end if;
                end if;
              end if;
            else
              if not exists (select * from werteindizes
                     join server on server.ID = serverID and server.verfahrenID = vid and testreg(server.servername, srv, srvv)
                     join section on section.ID = sectionID and testreg(section.name, sec, secv)
                     left join serverclasses on serverclasses.ID = serverclassesID
                     where accessID = aid and testreg(coalesce(serverclasses.name, ''), cla, clav)) then
                if not exists (select * from lwerteindizes
                       join server on server.ID = serverID and server.verfahrenID = vid and testreg(server.servername, srv, srvv)
                       join section on section.ID = sectionID and testreg(section.name, sec, secv)
                       left join serverclasses on serverclasses.ID = serverclassesID
                       where accessID = aid and testreg(coalesce(serverclasses.name, ''), cla, clav)) then
                  delete from ueberwachungspausen where ID = uid;
                  if nid is not NULL then
                    delete from ueberwachungspausen where ID = nid;
                  end if;
                end if;
              end if;
            end if;
          else
            if not exists (select * from werteindizes
                     join server on server.ID = serverID and server.verfahrenID = vid and testreg(server.servername, srv, srvv)
                     join section on section.ID = sectionID and testreg(section.name, sec, secv)
                     join teststep on teststep.ID = teststepID and testreg(teststep.name, tst, tstv)
                     left join serverclasses on serverclasses.ID = serverclassesID
                     where accessID = aid and testreg(coalesce(serverclasses.name, ''), cla, clav)) then
              if not exists (select * from lwerteindizes
                       join server on server.ID = serverID and server.verfahrenID = vid and testreg(server.servername, srv, srvv)
                       join section on section.ID = sectionID and testreg(section.name, sec, secv)
                       join teststep on teststep.ID = teststepID and testreg(teststep.name, tst, tstv)
                       left join serverclasses on serverclasses.ID = serverclassesID
                       where accessID = aid and testreg(coalesce(serverclasses.name, ''), cla, clav)) then
                delete from ueberwachungspausen where ID = uid;
                if nid is not NULL then
                  delete from ueberwachungspausen where ID = nid;
                end if;
              end if;
            end if;
          end if;
        else
          if not exists (select * from werteindizes
                     join server on server.ID = serverID and server.verfahrenID = vid and testreg(server.servername, srv, srvv)
                     join section on section.ID = sectionID and testreg(section.name, sec, secv)
                     join teststep on teststep.ID = teststepID and testreg(teststep.name, tst, tstv)
                     join teststepdetails on teststepdetails.ID = teststepdetailsID and testreg(teststepdetails.name, det, detv)
                     left join serverclasses on serverclasses.ID = serverclassesID
                     where accessID = aid and testreg(coalesce(serverclasses.name, ''), cla, clav)) then
            if not exists (select * from lwerteindizes
                       join server on server.ID = serverID and server.verfahrenID = vid and testreg(server.servername, srv, srvv)
                       join section on section.ID = sectionID and testreg(section.name, sec, secv)
                       join teststep on teststep.ID = teststepID and testreg(teststep.name, tst, tstv)
                       join groupfunctions as gf on gf.ID = lwerteindizes.groupfunctionsID
                       join teststepdetails
                         on teststepdetails.ID = teststepdetailsID and testreg(concat(gf.code, '[', left(period,1), '](', teststepdetails.name, ')'), det, detv)
                       left join serverclasses on serverclasses.ID = serverclassesID
                       where accessID = aid and testreg(coalesce(serverclasses.name, ''), cla, clav)) then
              delete from ueberwachungspausen where ID = uid;
              if nid is not NULL then
                delete from ueberwachungspausen where ID = nid;
              end if;
            end if;
          end if;
        end if;
      else
        if not exists (select * from werteindizes
                     join server on server.ID = serverID and server.verfahrenID = vid and testreg(server.servername, srv, srvv)
                     join section on section.ID = sectionID and testreg(section.name, sec, secv)
                     join teststep on teststep.ID = teststepID and testreg(teststep.name, tst, tstv)
                     join teststepdetails on teststepdetails.ID = teststepdetailsID and testreg(teststepdetails.name, det, detv)
                     join einheiten on einheiten.ID = einheitID and testreg(einheiten.name, unit, unitv)
                     left join serverclasses on serverclasses.ID = serverclassesID
                     where accessID = aid and testreg(coalesce(serverclasses.name, ''), cla, clav)) then
          if not exists (select * from lwerteindizes
                       join server on server.ID = serverID and server.verfahrenID = vid and testreg(server.servername, srv, srvv)
                       join section on section.ID = sectionID and testreg(section.name, sec, secv)
                       join teststep on teststep.ID = teststepID and testreg(teststep.name, tst, tstv)
                       join groupfunctions as gf on gf.ID = lwerteindizes.groupfunctionsID
                       join teststepdetails
                         on teststepdetails.ID = teststepdetailsID and testreg(concat(gf.code, '[', left(period,1), '](', teststepdetails.name, ')'), det, detv)
                       join einheiten on einheiten.ID = einheitID and testreg(einheiten.name, unit, unitv)
                       left join serverclasses on serverclasses.ID = serverclassesID
                       where accessID = aid and testreg(coalesce(serverclasses.name, ''), cla, clav)) then
            delete from ueberwachungspausen where ID = uid;
            if nid is not NULL then
              delete from ueberwachungspausen where ID = nid;
            end if;
          end if;
        end if;
      end if;

      fetch ucur into uid, nid, vid, aid, srv, srvv, cla, clav, sec, secv, tst, tstv, det, detv, unit, unitv;
    end while;
    close ucur;

  end//

GRANT EXECUTE on PROCEDURE cleansuspensions to loggingadmin@'localhost'//
