set @@character_set_client = 'utf8';

delimiter //

drop trigger if exists gautoisalive_au//
create trigger gautoisalive_au after update on gautoisalive
  for each row 
begin
  insert into changeprot
    (groupID, accessID, changedtable, tableID, userID, username, action,
     domain, classes, server, section, teststep, details, unit, newvalues)
  select NEW.groupID, NEW.accessID, 'gautoisalive', NEW.ID,
    coalesce(@userid,0), coalesce(@username,'SYSTEM'), 'update',
    showreg(NEW.domain, NEW.domain_v), showreg(NEW.classes, NEW.classes_v), showreg(NEW.server, NEW.server_v),
    showreg(NEW.section, NEW.section_v), showreg(NEW.teststep, NEW.teststep_v),
    showreg(NEW.details, NEW.details_v), showreg(NEW.einheit, NEW.einheit_v),
    concat('period=', NEW.maxperiods, '\nperiodunit=', intervalle.name, '\nmsglevel=', NEW.msglevel,
           '\nnotifymode=', NEW.notifymode, '\nautoclose=', NEW.autoclose, '\nmessage=', REPLACE(REPLACE(NEW.meldung, '\\', '\\\\'), '\n', '\\n'),
           '\ndestination1=', notifdestname(NEW.meldungszielID), '\ndestination2=', notifdestname(NEW.meldungsziel2ID),
           '\nremark=', REPLACE(REPLACE(NEW.bemerkungen, '\\', '\\\\'), '\n', '\\n'), '\nonlyifnoother=', NEW.nootherflag, '\nactive=', NEW.aktiv)
  from intervalle
  where NEW.TS != OLD.TS and intervalle.ID = NEW.intervalleID;
end//


drop trigger if exists gautoisalive_ai//
create trigger gautoisalive_ai after insert on gautoisalive
  for each row 
begin
  insert into changeprot
    (groupID, accessID, changedtable, tableID, userID, username, action,
     domain, classes, server, section, teststep, details, unit, newvalues)
  select NEW.groupID, NEW.accessID, 'gautoisalive', NEW.ID,
    coalesce(@userid,0), coalesce(@username,'SYSTEM'), 'insert',
    showreg(NEW.domain, NEW.domain_v), showreg(NEW.classes, NEW.classes_v), showreg(NEW.server, NEW.server_v),
    showreg(NEW.section, NEW.section_v), showreg(NEW.teststep, NEW.teststep_v),
    showreg(NEW.details, NEW.details_v), showreg(NEW.einheit, NEW.einheit_v),
    concat('period=', NEW.maxperiods, '\nperiodunit=', intervalle.name, '\nmsglevel=', NEW.msglevel,
           '\nnotifymode=', NEW.notifymode, '\nautoclose=', NEW.autoclose, '\nmessage=', REPLACE(REPLACE(NEW.meldung, '\\', '\\\\'), '\n', '\\n'),
           '\ndestination1=', notifdestname(NEW.meldungszielID), '\ndestination2=', notifdestname(NEW.meldungsziel2ID),
           '\nremark=', REPLACE(REPLACE(NEW.bemerkungen, '\\', '\\\\'), '\n', '\\n'), '\nonlyifnoother=', NEW.nootherflag, '\nactive=', NEW.aktiv)
  from intervalle
  where intervalle.ID = NEW.intervalleID;
end//


drop trigger if exists gautoisalive_bd//
create trigger gautoisalive_bd before delete on gautoisalive
  for each row
begin
  insert into changeprot
    (groupID, accessID, changedtable, tableID, userID, username, action,
     domain, classes, server, section, teststep, details, unit, newvalues)
  values
   (OLD.groupID, OLD.accessID, 'gautoisalive', OLD.ID,
    coalesce(@userid,0), coalesce(@username,'SYSTEM'), 'delete',
    showreg(OLD.domain, OLD.domain_v), showreg(OLD.classes, OLD.classes_v), showreg(OLD.server, OLD.server_v),
    showreg(OLD.section, OLD.section_v), showreg(OLD.teststep, OLD.teststep_v),
    showreg(OLD.details, OLD.details_v), showreg(OLD.einheit, OLD.einheit_v),
    coalesce(if(OLD.bemerkungen = @isaliveremark, '', concat('remark=', REPLACE(REPLACE(@isaliveremark, '\\', '\\\\'), '\n', '\\n'))),''));
end//

delimiter ;
