set @@character_set_client = 'utf8';

delimiter //

DROP FUNCTION IF EXISTS getlwertvb//
create function getlwertvb(lwid integer, von datetime, bis datetime, mode varchar(12))
                  returns varchar(30)
deterministic
sql security invoker
begin
  declare r, l double;
  declare ld datetime;
  declare f integer;
  case mode
    when 'min' then
          select min(wert) from lwerte
          where lwerteindizesID = lwid and von <= datum and datum <= bis
          into r;
    when 'max' then
          select max(wert) from lwerte
          where lwerteindizesID = lwid and von <= datum and datum <= bis
          into r;
    when 'avg' then
          select avg(wert), max(length(0+replace(wert, '.',''))) from lwerte
          where lwerteindizesID = lwid and von <= datum and datum <= bis
          into r, f;
          return round(r, f + 2 - locate('.', r));
    when 'last/avg' then
          select wert, datum from lwerte
          where lwerteindizesID = lwid and von <= datum and datum <= bis
          order by datum desc limit 1 into l, ld;
          select avg(wert), max(length(0+replace(wert, '.',''))) from lwerte
          where lwerteindizesID = lwid and von <= datum and datum < ld
          into r, f;
          if r != 0 then
            return round(l/r, f + 2 - locate('.', l/r));
          else
            return '';
          end if;
    when 'last/avg-1' then
          select wert, datum from lwerte
          where lwerteindizesID = lwid and von <= datum and datum <= bis
          order by datum desc limit 1 into l, ld;
          select avg(wert), max(length(0+replace(wert, '.',''))) from lwerte
          where lwerteindizesID = lwid and von <= datum and datum < ld
          into r, f;
          if r != 0 then
            return round(l/r-1, f + 2 - locate('.', l/r-1));
          else
            return '';
          end if;
    when 'dev' then
          select stddev_samp(wert) from lwerte
          where lwerteindizesID = lwid and von <= datum and datum <= bis
          into r;
    when 'sum' then
          select sum(wert) from lwerte
          where lwerteindizesID = lwid and von <= datum and datum <= bis
          into r;
    when 'max-min' then
          select max(wert)-min(wert) from lwerte
          where lwerteindizesID = lwid and von <= datum and datum <= bis
          into r;
    when 'last-first' then
          return (select wert from lwerte
                  where lwerteindizesID = lwid and von <= datum and datum <= bis
                  order by datum desc limit 1)
               - (select wert from lwerte
                  where lwerteindizesID = lwid and von <= datum and datum <= bis
                  order by datum limit 1);
    when 'last-first+' then
          set r = (select wert from lwerte
                  where lwerteindizesID = lwid and von <= datum and datum <= bis
                  order by datum desc limit 1)
               - (select wert from lwerte
                  where lwerteindizesID = lwid and von <= datum and datum <= bis
                  order by datum limit 1);
          if r < 0 then
            return '';
          end if;
    when 'last-first-' then
          set r = (select wert from lwerte
                  where lwerteindizesID = lwid and von <= datum and datum <= bis
                  order by datum desc limit 1)
               - (select wert from lwerte
                  where lwerteindizesID = lwid and von <= datum and datum <= bis
                  order by datum limit 1);
          if r > 0 then
            return '';
          end if;
    when 'differ' then
          return BINARY (select wert from lwerte
                  where lwerteindizesID = lwid and von <= datum and datum <= bis
                  order by datum desc limit 1)
              != BINARY (select wert from lwerte
                  where lwerteindizesID = lwid and von <= datum and datum <= bis
                  order by datum limit 1);
    when 'last' then
          select wert from lwerte
          where lwerteindizesID = lwid and von <= datum and datum <= bis
          order by datum desc limit 1
          into r;
    when 'first' then
          select wert from lwerte
          where lwerteindizesID = lwid and von <= datum and datum <= bis
          order by datum limit 1
          into r;
    when 'size' then
          select length(wert) from lwerte
          where lwerteindizesID = lwid and von <= datum and datum <= bis
          order by datum desc limit 1
          into r;
    when 'firstsize' then
          select length(wert) from lwerte
          where lwerteindizesID = lwid and von <= datum and datum <= bis
          order by datum limit 1
          into r;
    when 'count' then
          select count(*) from lwerte
          where lwerteindizesID = lwid and von <= datum and datum <= bis
          into r;
    when 'grad' then
      return gradientlvbextfilter(lwid, von, bis, '00:00:00', '24:00:00', '',
                                   '', '', '', '', '', '', '', '', '', '', '');
    when 'accel' then
      return accell(lwid, von, bis, '00:00:00', '24:00:00', '',
                     '', '', '', '', '', '', '', '', '', '', '');
    else
      return '';
  end case;
  return r;
end//

GRANT EXECUTE on FUNCTION getlwertvb to logginglesen@'localhost', loggingtest@'localhost'//
