set @@character_set_client = 'utf8';

delimiter //

DROP FUNCTION IF EXISTS getpwertvb//
create function getpwertvb(wid integer, von datetime, bis datetime, mode varchar(12))
                  returns varchar(30)
deterministic
sql security invoker
begin
  declare r, l varchar(20);
  declare ld datetime;
  declare f integer;
  case mode
    when 'min' then
          select min(wert+0) from pwerte
          where werteindizesID = wid and von <= datum and datum <= bis
          into r;
    when 'max' then
          select max(wert+0) from pwerte
          where werteindizesID = wid and von <= datum and datum <= bis
          into r;
    when 'avg' then
          select avg(wert+0), max(length(0+replace(wert, '.',''))) from pwerte
          where werteindizesID = wid and von <= datum and datum <= bis
          into r, f;
          return round(r, f + 2 - locate('.', r));
    when 'last/avg' then
          select wert+0, datum from pwerte
          where werteindizesID = wid and von <= datum and datum <= bis
          order by datum desc limit 1 into l, ld;
          select avg(wert+0), max(length(0+replace(wert,'.',''))) from pwerte
          where werteindizesID = wid and von <= datum and datum < ld
          into r, f;
          if r != 0 then
            return round(l/r, f + 2 - locate('.', l/r));
          else
            return NULL;
          end if;
    when 'last/avg-1' then
          select wert+0, datum from pwerte
          where werteindizesID = wid and von <= datum and datum <= bis
          order by datum desc limit 1 into l, ld;
          select avg(wert+0), max(length(0+replace(wert,'.',''))) from pwerte
          where werteindizesID = wid and von <= datum and datum < ld
          into r, f;
          if r != 0 then
            return round(l/r-1, f + 2 - locate('.', l/r-1));
          else
            return NULL;
          end if;
    when 'dev' then
          select stddev_samp(wert+0) from pwerte
          where werteindizesID = wid and von <= datum and datum <= bis
          into r;
    when 'sum' then
          select sum(wert+0), max(locate('.', reverse(wert))) from pwerte
          where werteindizesID = wid and von <= datum and datum <= bis
          into r, f;
          if f < 0 then
            set f = 0;
          end if;
          return round(r, f);
    when 'max-min' then
          select max(wert+0)-min(wert+0) from pwerte
          where werteindizesID = wid and von <= datum and datum <= bis
          into r;
    when 'last-first' then
          return (select wert from pwerte
                  where werteindizesID = wid and von <= datum and datum <= bis
                  order by datum desc limit 1)
               - (select wert from pwerte
                  where werteindizesID = wid and von <= datum and datum <= bis
                  order by datum limit 1);
    when 'last-first+' then
          set r = (select wert from pwerte
                  where werteindizesID = wid and von <= datum and datum <= bis
                  order by datum desc limit 1)
               - (select wert from pwerte
                  where werteindizesID = wid and von <= datum and datum <= bis
                  order by datum limit 1);
          if r < 0 then
            return NULL;
          end if;
    when 'last-first-' then
          set r = (select wert from pwerte
                  where werteindizesID = wid and von <= datum and datum <= bis
                  order by datum desc limit 1)
               - (select wert from pwerte
                  where werteindizesID = wid and von <= datum and datum <= bis
                  order by datum limit 1);
          if r > 0 then
            return NULL;
          end if;
    when 'differ' then
          return BINARY (select wert from pwerte
                  where werteindizesID = wid and von <= datum and datum <= bis
                  order by datum desc limit 1)
              != BINARY (select wert from pwerte
                  where werteindizesID = wid and von <= datum and datum <= bis
                  order by datum limit 1);
    when 'last' then
          select wert from pwerte
          where werteindizesID = wid and von <= datum and datum <= bis
          order by datum desc limit 1
          into r;
    when 'first' then
          select wert from pwerte
          where werteindizesID = wid and von <= datum and datum <= bis
          order by datum limit 1
          into r;
    when 'size' then
          select length(wert) from pwerte
          where werteindizesID = wid and von <= datum and datum <= bis
          order by datum desc limit 1
          into r;
    when 'firstsize' then
          select length(wert) from pwerte
          where werteindizesID = wid and von <= datum and datum <= bis
          order by datum limit 1
          into r;
    when 'count' then
          select count(*) from pwerte
          where werteindizesID = wid and von <= datum and datum <= bis
          into r;
    when 'grad' then
      return gradientpvb(wid, von, bis);
    when 'accel' then
      return accelp(wid, von, bis, '00:00:00', '24:00:00', '',
                    '', '', '', '', '', '', '', '', '', '', '');
    else
      return NULL;
  end case;
  return r;
end//

GRANT EXECUTE on FUNCTION getpwertvb to logginglesen@'localhost', loggingtest@'localhost', loggingadmin@'localhost'//
