set @@character_set_client = 'utf8';

delimiter //

drop trigger if exists isalive_au//
create trigger isalive_au after update on isalive
  for each row 
begin
  insert into changeprot
    (serverID, accessID, changedtable, tableID, domautoID, groupautoID,
     userID, username, action, server, section, teststep, details, unit, newvalues)
  select serverID, accessID, 'isalive', NEW.ID, NEW.autoisaliveID,
    NEW.groupautoID, coalesce(@userid,0), coalesce(@username,'SYSTEM'), 'update',
    servername, section.name, teststep.name, teststepdetails.name, einheiten.name,
    concat('period=', NEW.maxperiods, '\nperiodunit=', intervalle.name, '\nmsglevel=', NEW.msglevel,
           '\nnotifymode=', NEW.notifymode, '\nautoclose=', NEW.autoclose, '\nmessage=', REPLACE(REPLACE(NEW.meldung, '\\', '\\\\'), '\n', '\\n'),
           '\ndestination1=', notifdestname(NEW.meldungszielID), '\ndestination2=', notifdestname(NEW.meldungsziel2ID),
           '\nremark=', REPLACE(REPLACE(NEW.bemerkungen, '\\', '\\\\'), '\n', '\\n'), '\nactive=', NEW.aktiv, if(NEW.hidden, '\n[hidden]', ''),
           if(NEW.groupautoID > OLD.groupautoID, '\nconverted to group-auto', ''),
           if(NEW.autoisaliveID > OLD.autoisaliveID, '\nconverted to domain-auto', ''))
  from werteindizes, server, section, teststep, teststepdetails, einheiten,
    intervalle
  where NEW.TS != OLD.TS and werteindizes.ID = NEW.werteindizesID
    and server.ID = werteindizes.serverID and section.ID = werteindizes.sectionID
    and teststep.ID = werteindizes.teststepID and teststepdetails.ID = teststepdetailsID
    and einheiten.ID = teststepdetails.einheitID and intervalle.ID = NEW.intervalleID;
end//


drop trigger if exists isalive_ai//
create trigger isalive_ai after insert on isalive
  for each row 
begin
  insert into tisalive (ID) select NEW.ID;
  insert into changeprot
    (serverID, accessID, changedtable, tableID, domautoID, groupautoID,
     userID, username, action, server, section, teststep, details, unit, newvalues)
  select serverID, accessID, 'isalive', NEW.ID, NEW.autoisaliveID,
    NEW.groupautoID, coalesce(@userid,0), coalesce(@username,'SYSTEM'), 'insert',
    servername, section.name, teststep.name, teststepdetails.name, einheiten.name,
    concat('period=', NEW.maxperiods, '\nperiodunit=', intervalle.name, '\nmsglevel=', NEW.msglevel,
           '\nnotifymode=', NEW.notifymode, '\nautoclose=', NEW.autoclose, '\nmessage=', REPLACE(REPLACE(NEW.meldung, '\\', '\\\\'), '\n', '\\n'),
           '\ndestination1=', notifdestname(NEW.meldungszielID), '\ndestination2=', notifdestname(NEW.meldungsziel2ID),
           '\nremark=', REPLACE(REPLACE(NEW.bemerkungen, '\\', '\\\\'), '\n', '\\n'), '\nactive=', NEW.aktiv,
           if(NEW.hidden, '\n[hidden]', ''))
  from werteindizes, server, section, teststep, teststepdetails, einheiten,
    intervalle
  where werteindizes.ID = NEW.werteindizesID
    and server.ID = werteindizes.serverID and section.ID = werteindizes.sectionID
    and teststep.ID = werteindizes.teststepID and teststepdetails.ID = teststepdetailsID
    and einheiten.ID = teststepdetails.einheitID and intervalle.ID = NEW.intervalleID;
end//


drop trigger if exists isalive_bd//
create trigger isalive_bd before delete on isalive
  for each row 
begin
  delete from tisalive where tisalive.ID = OLD.ID;
  insert into changeprot
    (serverID, accessID, changedtable, tableID, domautoID, groupautoID,  userID, username, action,
     server, section, teststep, details, unit, newvalues)
  select serverID, accessID, 'isalive', OLD.ID, OLD.autoisaliveID,
    OLD.groupautoID, coalesce(@userid,0), coalesce(@username,'SYSTEM'), 'delete',
    servername, section.name, teststep.name, teststepdetails.name, einheiten.name,
    coalesce(if(OLD.bemerkungen = @isaliveremark, '', concat('remark=', REPLACE(REPLACE(@isaliveremark, '\\', '\\\\'), '\n', '\\n'))),'')
  from werteindizes, server, section, teststep, teststepdetails, einheiten
  where werteindizes.ID = OLD.werteindizesID
    and server.ID = werteindizes.serverID and section.ID = werteindizes.sectionID
    and teststep.ID = werteindizes.teststepID and teststepdetails.ID = teststepdetailsID
    and einheiten.ID = teststepdetails.einheitID;
end//

delimiter ;
