set @@character_set_client = 'utf8';

delimiter //

drop trigger if exists lwertelimits_au//
create trigger lwertelimits_au after update on lwertelimits
  for each row 
begin
  insert into changeprot
    (serverID, accessID, changedtable, tableID, domautoID, groupautoID,
     userID, username, action, server, section, teststep, details, unit, newvalues)
  select serverID, accessID, 'lwertelimits', NEW.ID, NEW.autollimitsID, NEW.groupautoID,
    coalesce(@userid,0), coalesce(@username,'SYSTEM'), 'update',
    servername, section.name, teststep.name,
    concat(cg.code,'[',left(period,1),'](',teststepdetails.name,')'), einheiten.name,
    concat('function=', g.code, '\nover=', NEW.anzmittel, '\nrelation=', NEW.vergleich,
           '\ninfolevel=', NEW.infowert, '\nwarnlevel=', NEW.warnwert, '\nerrorlevel=', NEW.errorwert,
           '\nnotifymode=', NEW.notifymode, '\nmessage=', REPLACE(REPLACE(NEW.meldung, '\\', '\\\\'), '\n', '\\n'),
           '\ndestination1=', notifdestname(NEW.meldungszielID), '\ndest1levels=',
           if(find_in_set('INFO', NEW.ziel1level), 'I', ''),
           if(find_in_set('WARN', NEW.ziel1level), 'W', ''),
           if(find_in_set('ERROR', NEW.ziel1level), 'F', ''), '\ndestination2=',
           notifdestname(NEW.meldungsziel2ID), '\ndest2levels=',
           if(find_in_set('INFO', NEW.ziel2level), 'I', ''),
           if(find_in_set('WARN', NEW.ziel2level), 'W', ''),
           if(find_in_set('ERROR', NEW.ziel2level), 'F', ''), '\nremark=',
           REPLACE(REPLACE(NEW.bemerkungen, '\\', '\\\\'), '\n', '\\n'), '\nactive=', NEW.aktiv,
           if(NEW.hidden, '\n[hidden]', ''),
           if(NEW.groupautoID > OLD.groupautoID, '\nconverted to group-auto', ''),
           if(NEW.autollimitsID > OLD.autollimitsID, '\nconverted to domain-auto', ''))
  from lwerteindizes
  join server on server.ID = serverID
  join section on section.ID = sectionID
  join teststep on teststep.ID = teststepID
  join teststepdetails on teststepdetails.ID = teststepdetailsID
  join einheiten on einheiten.ID = einheitID
  join groupfunctions as cg on cg.ID = lwerteindizes.groupfunctionsID
  join groupfunctions as g on g.ID = NEW.groupfunctionsID
  where NEW.TS != OLD.TS and lwerteindizes.ID = NEW.lwerteindizesID;
  if (not NEW.hidden and OLD.hidden) OR (NEW.aktiv = '1' and OLD.aktiv = '0') then
    update tlwertelimits join lwerteindizes as lwi on lwi.ID = NEW.lwerteindizesID set
        tlwertelimits.lasttestdate = case period
                when 'Week' then date(lwi.lkdate) + interval 4 day
                when 'Month' then date(lwi.lkdate) + interval 15 day
                else date(lwi.lkdate) + interval '23 59' hour_minute end
      where tlwertelimits.ID = NEW.ID AND lwi.lkdate != '0000-00-00';
  end if;
end//


drop trigger if exists lwertelimits_ai//
create trigger lwertelimits_ai after insert on lwertelimits
  for each row 
begin
  insert into tlwertelimits (ID) select NEW.ID;
  insert into changeprot
    (serverID, accessID, changedtable, tableID, domautoID, groupautoID,
     userID, username, action, server, section, teststep, details, unit, newvalues)
  select serverID, accessID, 'lwertelimits', NEW.ID, NEW.autollimitsID, NEW.groupautoID,
    coalesce(@userid,0), coalesce(@username,'SYSTEM'), 'insert',
    servername, section.name, teststep.name,
    concat(cg.code,'[',left(period,1),'](',teststepdetails.name,')'), einheiten.name,
    concat('function=', g.code, '\nover=', NEW.anzmittel, '\nrelation=', NEW.vergleich,
           '\ninfolevel=', NEW.infowert, '\nwarnlevel=', NEW.warnwert, '\nerrorlevel=', NEW.errorwert,
           '\nnotifymode=', NEW.notifymode, '\nmessage=', REPLACE(REPLACE(NEW.meldung, '\\', '\\\\'), '\n', '\\n'),
           '\ndestination1=', notifdestname(NEW.meldungszielID), '\ndest1levels=',
           if(find_in_set('INFO', NEW.ziel1level), 'I', ''),
           if(find_in_set('WARN', NEW.ziel1level), 'W', ''),
           if(find_in_set('ERROR', NEW.ziel1level), 'F', ''), '\ndestination2=',
           notifdestname(NEW.meldungsziel2ID), '\ndest2levels=',
           if(find_in_set('INFO', NEW.ziel2level), 'I', ''),
           if(find_in_set('WARN', NEW.ziel2level), 'W', ''),
           if(find_in_set('ERROR', NEW.ziel2level), 'F', ''), '\nremark=',
           REPLACE(REPLACE(NEW.bemerkungen, '\\', '\\\\'), '\n', '\\n'), '\nactive=', NEW.aktiv,
           if(NEW.hidden, '\n[hidden]', ''))
  from lwerteindizes
  join server on server.ID = serverID
  join section on section.ID = sectionID
  join teststep on teststep.ID = teststepID
  join teststepdetails on teststepdetails.ID = teststepdetailsID
  join einheiten on einheiten.ID = einheitID
  join groupfunctions as cg on cg.ID = lwerteindizes.groupfunctionsID
  join groupfunctions as g on g.ID = NEW.groupfunctionsID
  where lwerteindizes.ID = NEW.lwerteindizesID;
end//


drop trigger if exists lwertelimits_bd//
create trigger lwertelimits_bd before delete on lwertelimits
  for each row 
begin
  delete from tlwertelimits where tlwertelimits.ID = OLD.ID;
  insert into changeprot
    (serverID, accessID, changedtable, tableID, domautoID, groupautoID, userID, username, action,
     server, section, teststep, details, unit, newvalues)
  select serverID, accessID, 'lwertelimits', OLD.ID, OLD.autollimitsID, OLD.groupautoID,
    coalesce(@userid,0), coalesce(@username,'SYSTEM'), 'delete',
    servername, section.name, teststep.name,
    concat(cg.code,'[',left(period,1),'](',teststepdetails.name,')'), einheiten.name,
    coalesce(if(OLD.bemerkungen = @complimitsremark, '', concat('remark=', REPLACE(REPLACE(@complimitsremark, '\\', '\\\\'), '\n', '\\n'))),'')
  from lwerteindizes
  join server on server.ID = serverID
  join section on section.ID = sectionID
  join teststep on teststep.ID = teststepID
  join teststepdetails on teststepdetails.ID = teststepdetailsID
  join einheiten on einheiten.ID = einheitID
  join groupfunctions as cg on cg.ID = lwerteindizes.groupfunctionsID
  where lwerteindizes.ID = OLD.lwerteindizesID;
end//

delimiter ;
