set @@character_set_client = 'utf8';

delimiter //
DROP FUNCTION IF EXISTS getrange//
create function getrange(rset varchar(100)) returns varchar(100)
  deterministic
  sql security invoker
begin
  declare i, j, k, l integer;
  declare r, ret varchar(100);

  set k = instr(rset, ',');
  if k = 0 then
    return rset;
  end if;

  set i = left(rset, k-1);
  set ret = i;
  set j = i;
  set r = substring(rset, k+1);
  set k = instr(r, ',');
  while k do
    set l = left(r, k-1);
    set r = substring(r, k+1);
    set k = instr(r, ',');
    if l > j+1 then
      if j > i+1 then
        set ret = concat(ret, '-', j, ',', l);
      elseif j > i then
        set ret = concat(ret, ',', j, ',', l);
      else
        set ret = concat(ret, ',', l);
      end if;
      set i = l;
    end if;
    set j = l;
  end while;
  if r-1 = j AND j > i then
    return concat(ret, '-', r);
  elseif j > i then
    return concat(ret, '-', j, ',', r);
  else
    return concat(ret, ',', r);
  end if;
end//

-- rnge: Range, die convertiert wird
-- mini: minimaler Wert in Range
-- maxi: maximaler Wert in Range
-- r:    zu verarbeitender Rest
-- rset: Ergebnisset
-- z:    Ziffern zu Zahl zusammensetzen
-- c:    current character
-- lc:   last character

DROP FUNCTION IF EXISTS setrange//
create function setrange(rnge varchar(100), mini integer unsigned, maxi integer unsigned)
         returns varchar(100)
  deterministic
  sql security invoker
begin
  declare i integer;
  declare r, rset varchar(1000);
  declare z varchar(10);
  declare c, lc varbinary(1);

  set rset = '';
  set z = '';
  set i = -1;
  set r = rnge;
  set lc = '';
  while r != '' do 
    set c = left(r, 1);
    if c REGEXP '[0-9]' AND lc != ' ' then
      set z = concat(z, c);
      set lc = c;
    elseif c = '-' and z != '' then
      set i = z;
      set z = '';
      set lc = c;
    elseif c != ' ' then
      if z != '' then
        if i >= 0 then
          while i <= z do
            set rset = concat(rset, ',', i);
            set i = i + 1;
          end while;
        else
          set rset = concat(rset, ',', z);
        end if;
        set i = -1;
      elseif i >= 0 then
        set rset = concat(rset, ',', i);
        set i = -1;
      end if;
      if c REGEXP '[0-9]' then
        set z = c;
      else
        set z = '';
      end if;
      set lc = c;
    elseif lc REGEXP '[0-9]' then
      set lc = c;
    end if;
    set r = substring(r, 2);
  end while;
  if z != '' then
    if i >= 0 then
      while i <= z do
        set rset = concat(rset, ',', i);
        set i = i + 1;
      end while;
    else
      set rset = concat(rset, ',', z);
    end if;
  elseif i >= 0 then
    set rset = concat(rset, ',', i);
  end if;
  set r = '';
  set i = mini;
  while i <= maxi do
    if find_in_set(i, rset) then
      set r = concat(r, ',', i);
    end if;
    set i = i + 1;
  end while;

  return trim(leading ',' from r);

end//


DROP FUNCTION IF EXISTS setrangenextday//
create function setrangenextday(rnge varchar(100), mini integer unsigned, maxi integer unsigned)
         returns varchar(100)
  deterministic
  sql security invoker
begin
  declare i integer;
  declare r, rset varchar(100);

  if rnge = '' then
    return '';
  end if;

  set rset = setrange(rnge, mini, maxi);
  set r = '';
  set i = mini;
  while i <= maxi do
    if find_in_set(i, rset) then
      set r = concat(r, ',', i+1);
    end if;
    set i = i + 1;
  end while;

  return trim(leading ',' from r);

end//


-- is_subrange
-- testet, ob sbrng subrange des rng ist

DROP FUNCTION IF EXISTS is_subrange//
create function is_subrange(sbrng varchar(100), rng varchar(100), mini integer unsigned, maxi integer unsigned)
         returns tinyint
  deterministic
  sql security invoker
begin
  declare i integer;

  if rng = '' then
    return 1;
  end if;

  set i = mini;
  while i <= maxi do
    if find_in_set(i, sbrng) and not find_in_set(i,rng) then
      return 0;
    end if;
    set i = i + 1;
  end while;

  return 1;

end//


-- allowed_range
-- testet, folgende Tage bis enddate erlaubt sind

DROP FUNCTION IF EXISTS allowed_range//
create function allowed_range(startdate datetime, enddate datetime, mdays varchar(90),
                             weekdays set('0','1','2','3','4','5','6'))
         returns datetime
  deterministic
  sql security invoker
begin
  declare td, sd, ed date;

  set ed = date(enddate);
  set sd = date(startdate);

  if ed = sd then
    return enddate;
  end if;

  set td = sd + interval 1 day;
  while td <= ed AND (mdays = '' OR find_in_set(day(td), mdays)) AND find_in_set(weekday(td), weekdays) do
    set sd = td;
    set td = sd + interval 1 day;
  end while;

  if sd < ed then
    return td - interval 1 second;
  else 
    return enddate;
  end if;

end//
