set @@character_set_client = 'utf8';

-- ----------------------------------------------
-- removemastergroups.sql
--
-- Wird aufgerufen wenn von einer
-- Gruppe Mastergruppen entfernt werden
--
-- ----------------------------------------------

delimiter //


DROP procedure IF EXISTS removemastergroups//
create procedure removemastergroups(groupid integer unsigned, maids varchar(10000))
  deterministic
  sql security invoker
 begin

  create temporary table loggingtmp.wids (
    ID integer unsigned not null default '0',
    primary key(ID));
--
--
-- Limits

  insert into loggingtmp.wids
    select distinct werteindizesID
    from wertelimits
    join gautolimits as ga on ga.ID = wertelimits.groupautoID and find_in_set(ga.groupID, maids)
    where wertelimits.slavegroupID = groupid;

  delete wertelimits from wertelimits
    join gautolimits as ga on ga.ID = wertelimits.groupautoID and find_in_set(ga.groupID, maids)
    where wertelimits.slavegroupID = groupid;

  create temporary table loggingtmp.ano (primary key(werteindizesID))
    select l.werteindizesID, min(ga.nootherflag) as mnoflg
    from loggingtmp.wids
    join wertelimits as l on l.werteindizesID = wids.ID
    join gautolimits as ga on ga.ID = l.groupautoID
    group by wids.ID;
  create temporary table loggingtmp.om (primary key(werteindizesID, groupID))
    select werteindizesID, ga.groupID
    from wertelimits
    join loggingtmp.ano using (werteindizesID)
    join gautolimits as ga on ga.ID = wertelimits.groupautoID and ga.overridemaster
    group by werteindizesID, ga.groupID;
  update wertelimits as l
    join loggingtmp.ano using(werteindizesID)
    join gautolimits as ga on ga.ID = l.groupautoID
    left join loggingtmp.om
      on om.werteindizesID = l.werteindizesID and om.groupID = l.slavegroupID
    set l.hidden = if(ga.nootherflag, not ano.mnoflg, om.werteindizesID is not NULL)
    where ga.nootherflag OR l.slavegroupID is not NULL;
  drop temporary table loggingtmp.om, loggingtmp.ano;
--
--
-- isAlive

  delete from loggingtmp.wids;
  insert into loggingtmp.wids
    select distinct werteindizesID
    from isalive
    join gautoisalive as ga on ga.ID = isalive.groupautoID and find_in_set(ga.groupID, maids)
    where isalive.slavegroupID = groupid;

  delete isalive from isalive
    join gautoisalive as ga on ga.ID = isalive.groupautoID and find_in_set(ga.groupID, maids)
    where isalive.slavegroupID = groupid;

  create temporary table loggingtmp.ano (primary key(werteindizesID))
    select i.werteindizesID, min(ga.nootherflag) as mnoflg
    from loggingtmp.wids
    join isalive as i on i.werteindizesID = wids.ID
    join gautoisalive as ga on ga.ID = i.groupautoID
    group by wids.ID;
  create temporary table loggingtmp.om (primary key(werteindizesID, groupID))
    select werteindizesID, ga.groupID
    from isalive
    join loggingtmp.ano using (werteindizesID)
    join gautoisalive as ga on ga.ID = isalive.groupautoID and ga.overridemaster
    group by werteindizesID, ga.groupID;
  update isalive
    join loggingtmp.ano using(werteindizesID)
    join gautoisalive on gautoisalive.ID = isalive.groupautoID
    left join loggingtmp.om
      on om.werteindizesID = isalive.werteindizesID and om.groupID = isalive.slavegroupID
    set isalive.hidden = if(gautoisalive.nootherflag, not ano.mnoflg, om.werteindizesID is not NULL)
    where gautoisalive.nootherflag OR isalive.slavegroupID is not NULL;
  drop temporary table loggingtmp.om, loggingtmp.ano;
--
--
-- kompr. Limits

  delete from loggingtmp.wids;
  insert into loggingtmp.wids
    select distinct lwerteindizesID
    from lwertelimits
    join gautoclimits as ga on ga.ID = lwertelimits.groupautoID and find_in_set(ga.groupID, maids)
    where lwertelimits.slavegroupID = groupid;

  delete lwertelimits from lwertelimits
    join gautoclimits as ga on ga.ID = lwertelimits.groupautoID and find_in_set(ga.groupID, maids)
    where lwertelimits.slavegroupID = groupid;

  create temporary table loggingtmp.ano (primary key(lwerteindizesID))
    select l.lwerteindizesID, min(ga.nootherflag) as mnoflg
    from loggingtmp.wids
    join lwertelimits as l on l.lwerteindizesID = wids.ID
    join gautoclimits as ga on ga.ID = l.groupautoID
    group by wids.ID;
  create temporary table loggingtmp.om (primary key(lwerteindizesID, groupID))
    select lwerteindizesID, ga.groupID
    from lwertelimits
    join loggingtmp.ano using (lwerteindizesID)
    join gautoclimits as ga on ga.ID = lwertelimits.groupautoID and ga.overridemaster
    group by lwerteindizesID, ga.groupID;
  update lwertelimits
    join loggingtmp.ano using(lwerteindizesID)
    join gautoclimits as ga on ga.ID = lwertelimits.groupautoID
    left join loggingtmp.om
      on om.lwerteindizesID = lwertelimits.lwerteindizesID and om.groupID = lwertelimits.slavegroupID
    set lwertelimits.hidden = if(ga.nootherflag, NOT ano.mnoflg, om.lwerteindizesID is not NULL)
    where ga.nootherflag OR lwertelimits.slavegroupID is not NULL;
  drop temporary table loggingtmp.om, loggingtmp.ano, loggingtmp.wids;
--
--
-- Kombilimits

  create temporary table loggingtmp.sstids (
    serverID integer unsigned not null default '0',
    sectionID integer unsigned not null default '0',
    teststepID integer unsigned not null default '0',
    accessID integer unsigned not null default '0',
    primary key(serverID, sectionID, teststepID, accessID));
  insert into loggingtmp.sstids
    select distinct serverID, sectionID, teststepID, kombilimits.accessID
    from kombilimits
    join gautocombilimits as ga on ga.ID = kombilimits.groupautoID and find_in_set(ga.groupID, maids)
    where kombilimits.slavegroupID = groupid;

  delete kombilimits from kombilimits
    join gautocombilimits as ga on ga.ID = kombilimits.groupautoID and find_in_set(ga.groupID, maids)
    where kombilimits.slavegroupID = groupid;

  create temporary table loggingtmp.ano (primary key(serverID, sectionID, teststepID, accessID))
    select sstids.serverID, sstids.sectionID, sstids.teststepID, sstids.accessID,
      min(ga.nootherflag) as mnoflg
    from loggingtmp.sstids
    join kombilimits as k
      on k.serverID = sstids.serverID and k.sectionID = sstids.sectionID
        and k.teststepID = sstids.teststepID and k.accessID = sstids.accessID
    join gautocombilimits as ga on ga.ID = k.groupautoID
    group by sstids.serverID, sstids.sectionID, sstids.teststepID, sstids.accessID;
  create temporary table loggingtmp.om (primary key(serverID, sectionID, teststepID, groupID, accessID))
    select serverID, sectionID, teststepID, ga.groupID, ano.accessID
    from kombilimits
    join loggingtmp.ano using (serverID, sectionID, teststepID, accessID)
    join gautocombilimits as ga on ga.ID = kombilimits.groupautoID and ga.overridemaster
    group by serverID, sectionID, teststepID, ga.groupID;
  update kombilimits
    join loggingtmp.ano using(serverID, sectionID, teststepID, accessID)
    join gautocombilimits as ga on ga.ID = kombilimits.groupautoID
    left join loggingtmp.om
      on om.serverID = kombilimits.serverID and om.sectionID = kombilimits.sectionID
        and om.teststepID = kombilimits.teststepID and om.groupID = kombilimits.slavegroupID
    set kombilimits.hidden = if(ga.nootherflag, NOT ano.mnoflg, om.serverID is not NULL)
    where ga.nootherflag OR kombilimits.slavegroupID is not NULL;
  drop temporary table loggingtmp.om, loggingtmp.ano, loggingtmp.sstids;

--
--
-- Compression
  delete komprimierungids from komprimierungids
    join gautocompression as ga on ga.ID = komprimierungids.groupautoID and find_in_set(ga.groupID, maids)
    where komprimierungids.slavegroupID = groupid;


end//
