set @@character_set_client = 'utf8';

delimiter //

drop trigger if exists wertelimits_au//
create trigger wertelimits_au after update on wertelimits
  for each row 
begin
  insert into changeprot
    (serverID, accessID, changedtable, tableID, domautoID, groupautoID,
     userID, username, action, server, section, teststep, details, unit, newvalues)
  select serverID, accessID, 'wertelimits', NEW.ID, NEW.autolimitsID, NEW.groupautoID,
    coalesce(@userid,0), coalesce(@username,'SYSTEM'), 'update',
    servername, section.name, teststep.name, teststepdetails.name, einheiten.name,
    concat('function=', g.code, '\nover=', NEW.anzmittel, '\nrelation=', NEW.vergleich,
           '\ninfolevel=', NEW.infowert, '\nwarnlevel=', NEW.warnwert, '\nerrorlevel=',
           NEW.errorwert, '\nexclude=', NEW.exclude, '\nnotifymode=', NEW.notifymode,
           '\nmessage=', REPLACE(REPLACE(NEW.meldung, '\\', '\\\\'), '\n', '\\n'), '\ndestination1=',
           notifdestname(NEW.meldungszielID), '\ndest1levels=',
           if(find_in_set('INFO', NEW.ziel1level), 'I', ''),
           if(find_in_set('WARN', NEW.ziel1level), 'W', ''),
           if(find_in_set('ERROR', NEW.ziel1level), 'F', ''), '\ndestination2=',
           notifdestname(NEW.meldungsziel2ID), '\ndest2levels=',
           if(find_in_set('INFO', NEW.ziel2level), 'I', ''),
           if(find_in_set('WARN', NEW.ziel2level), 'W', ''),
           if(find_in_set('ERROR', NEW.ziel2level), 'F', ''), '\nremark=',
           REPLACE(REPLACE(NEW.bemerkungen, '\\', '\\\\'), '\n', '\\n'), '\nactive=', NEW.aktiv,
           if(NEW.hidden, '\n[hidden]', ''),
           if(NEW.groupautoID > OLD.groupautoID, '\nconverted to group-auto', ''),
           if(NEW.autolimitsID > OLD.autolimitsID, '\nconverted to domain-auto', ''))
  from werteindizes, server, section, teststep, teststepdetails, einheiten,
    groupfunctions as g
  where NEW.TS != OLD.TS and werteindizes.ID = NEW.werteindizesID
    and server.ID = werteindizes.serverID and section.ID = werteindizes.sectionID
    and teststep.ID = werteindizes.teststepID and teststepdetails.ID = teststepdetailsID
    and einheiten.ID = teststepdetails.einheitID and g.ID = NEW.groupfunctionsID;
  if (not NEW.hidden and OLD.hidden) OR (NEW.aktiv = '1' and OLD.aktiv = '0') then
    update twertelimits, letztewerte set
      twertelimits.lasttestdate = coalesce(letztewerte.lastdatum + interval 1 second, '0000-00-00 00:00:00')
    where twertelimits.ID = NEW.ID and letztewerte.ID = NEW.werteindizesID;
  end if;
end//

drop trigger if exists wertelimits_ai//
create trigger wertelimits_ai after insert on wertelimits
  for each row 
begin
  insert into twertelimits (ID, lasttestdate)
    select NEW.ID, coalesce(lw.lastdatum + interval 1 second, '0000-00-00 00:00:00')
      from letztewerte as lw where lw.ID = NEW.werteindizesID;
  insert into changeprot
    (serverID, accessID, changedtable, tableID, domautoID, groupautoID,
     userID, username, action, server, section, teststep, details, unit, newvalues)
  select serverID, accessID, 'wertelimits', NEW.ID, NEW.autolimitsID, NEW.groupautoID,
    coalesce(@userid,0), coalesce(@username,'SYSTEM'), 'insert',
    servername, section.name, teststep.name, teststepdetails.name, einheiten.name,
    concat('function=', g.code, '\nover=', NEW.anzmittel, '\nrelation=', NEW.vergleich,
           '\ninfolevel=', NEW.infowert, '\nwarnlevel=', NEW.warnwert, '\nerrorlevel=',
           NEW.errorwert, '\nexclude=', NEW.exclude, '\nnotifymode=', NEW.notifymode,
           '\nmessage=', REPLACE(REPLACE(NEW.meldung, '\\', '\\\\'), '\n', '\\n'), '\ndestination1=',
           notifdestname(NEW.meldungszielID), '\ndest1levels=',
           if(find_in_set('INFO', NEW.ziel1level), 'I', ''),
           if(find_in_set('WARN', NEW.ziel1level), 'W', ''),
           if(find_in_set('ERROR', NEW.ziel1level), 'F', ''), '\ndestination2=',
           notifdestname(NEW.meldungsziel2ID), '\ndest2levels=',
           if(find_in_set('INFO', NEW.ziel2level), 'I', ''),
           if(find_in_set('WARN', NEW.ziel2level), 'W', ''),
           if(find_in_set('ERROR', NEW.ziel2level), 'F', ''), '\nremark=',
           REPLACE(REPLACE(NEW.bemerkungen, '\\', '\\\\'), '\n', '\\n'), '\nactive=', NEW.aktiv,
           if(NEW.hidden, '\n[hidden]', ''))
  from werteindizes, server, section, teststep, teststepdetails, einheiten,
    groupfunctions as g
  where werteindizes.ID = NEW.werteindizesID
    and server.ID = werteindizes.serverID and section.ID = werteindizes.sectionID
    and teststep.ID = werteindizes.teststepID and teststepdetails.ID = teststepdetailsID
    and einheiten.ID = teststepdetails.einheitID and g.ID = NEW.groupfunctionsID;
end//


drop trigger if exists wertelimits_bd//
create trigger wertelimits_bd before delete on wertelimits
  for each row 
begin
  delete from twertelimits where twertelimits.ID = OLD.ID;
  insert into changeprot
    (serverID, accessID, changedtable, tableID, domautoID, groupautoID,
     userID, username, action, server, section, teststep, details, unit, newvalues)
  select serverID, accessID, 'wertelimits', OLD.ID, OLD.autolimitsID, OLD.groupautoID,
    coalesce(@userid,0), coalesce(@username,'SYSTEM'), 'delete',
    servername, section.name, teststep.name, teststepdetails.name, einheiten.name,
    coalesce(if(OLD.bemerkungen = @limitsremark, '', concat('remark=', REPLACE(REPLACE(@limitsremark, '\\', '\\\\'), '\n', '\\n'))),'')
  from werteindizes, server, section, teststep, teststepdetails, einheiten
  where werteindizes.ID = OLD.werteindizesID and server.ID = werteindizes.serverID
    and section.ID = werteindizes.sectionID and teststep.ID = werteindizes.teststepID
    and teststepdetails.ID = teststepdetailsID and einheiten.ID = teststepdetails.einheitID;
end//

delimiter ;
